<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\ActivityBlueprint;

class ActivityBlueprintAdminController extends Controller
{
    public function index()
    {
        $blueprints = ActivityBlueprint::all();
        return view('admin.activity_blueprints.index', compact('blueprints'));
    }

    public function create()
    {
        return view('admin.activity_blueprints.create');
    }

    public function store(Request $request)
    {
        $data = $request->validate([
            'trigger_tag' => 'required|string',
            'title' => 'required|string',
            'description' => 'nullable|string',
            'default_duration' => 'required|integer',
            'default_tags' => 'nullable|string',
            'eq_profile' => 'nullable|string',
            'active' => 'boolean',
        ]);

        $data['default_tags'] = array_map('trim', explode(',', $data['default_tags'] ?? ''));
        $data['eq_profile'] = array_map('intval', explode(',', $data['eq_profile'] ?? ''));

        ActivityBlueprint::create($data);

        return redirect()->route('admin.activity_blueprints.index')->with('success', 'Activity created.');
    }

    public function edit($id)
    {
        $blueprint = ActivityBlueprint::findOrFail($id);
        return view('admin.activity_blueprints.edit', compact('blueprint'));
    }

    public function update(Request $request, $id)
    {
        $blueprint = ActivityBlueprint::findOrFail($id);

        $data = $request->validate([
            'title' => 'required|string',
            'description' => 'nullable|string',
            'default_duration' => 'required|integer',
            'default_tags' => 'nullable|string',
            'eq_profile' => 'nullable|string',
            'active' => 'boolean',
        ]);

        $data['default_tags'] = array_map('trim', explode(',', $data['default_tags'] ?? ''));
        $data['eq_profile'] = array_map('intval', explode(',', $data['eq_profile'] ?? ''));

        $blueprint->update($data);

        return redirect()->route('admin.activity_blueprints.index')->with('success', 'Activity updated.');
    }

    public function destroy($id)
    {
        ActivityBlueprint::destroy($id);
        return redirect()->route('admin.activity_blueprints.index')->with('success', 'Deleted.');
    }
}
