<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\GuidedSessionTemplate;

class GuidedSessionTemplateAdminController extends Controller
{
    public function index()
    {
        $templates = GuidedSessionTemplate::all();
        return view('admin.guided_sessions.index', compact('templates'));
    }

    public function create()
    {
        return view('admin.guided_sessions.create');
    }

    public function store(Request $request)
    {
        $data = $request->validate([
            'title' => 'required',
            'description' => 'nullable',
            'goal_tags' => 'nullable',
            'mood_tags' => 'nullable',
            'sound_tags' => 'nullable',
            'cannabis_tags' => 'nullable',
            'use_case_tags' => 'nullable',
            'time_of_day' => 'nullable',
            'icon' => 'nullable|string',
            'active' => 'boolean',
        ]);

        // Cast comma-separated strings into arrays
        foreach (['goal_tags','mood_tags','sound_tags','cannabis_tags','use_case_tags'] as $field) {
            if (!empty($data[$field])) {
                $data[$field] = array_map('trim', explode(',', $data[$field]));
            }
        }

        GuidedSessionTemplate::create($data);

        return redirect()->route('admin.guided_sessions.index')->with('success', 'Session created');
    }

    public function edit($id)
    {
        $template = GuidedSessionTemplate::findOrFail($id);
        return view('admin.guided_sessions.edit', compact('template'));
    }

    public function update(Request $request, $id)
    {
        $template = GuidedSessionTemplate::findOrFail($id);

        $data = $request->validate([
            'title' => 'required',
            'description' => 'nullable',
            'goal_tags' => 'nullable',
            'mood_tags' => 'nullable',
            'sound_tags' => 'nullable',
            'cannabis_tags' => 'nullable',
            'use_case_tags' => 'nullable',
            'time_of_day' => 'nullable',
            'icon' => 'nullable|string',
            'active' => 'boolean',
        ]);

        foreach (['goal_tags','mood_tags','sound_tags','cannabis_tags','use_case_tags'] as $field) {
            if (!empty($data[$field])) {
                $data[$field] = array_map('trim', explode(',', $data[$field]));
            }
        }

        $template->update($data);

        return redirect()->route('admin.guided_sessions.index')->with('success', 'Session updated');
    }
}
