<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\VibeOption;

class VibeOptionAdminController extends Controller
{
    public function index()
    {
        $vibes = VibeOption::all();
        return view('admin.vibe_options.index', compact('vibes'));
    }

    public function create()
    {
        return view('admin.vibe_options.create');
    }

    public function store(Request $request)
    {
        $data = $request->validate([
            'key' => 'required|unique:vibe_options,key',
            'emoji' => 'required',
            'label' => 'required',
            'message' => 'required',
            'eq_strategy' => 'nullable|string',
            'home_focus' => 'nullable|string',
            'active' => 'boolean',
        ]);

        VibeOption::create($data);
        return redirect()->route('admin.vibe_options.index')->with('success', 'Vibe created');
    }

    public function edit($id)
    {
        $vibe = VibeOption::findOrFail($id);
        return view('admin.vibe_options.edit', compact('vibe'));
    }

    public function update(Request $request, $id)
    {
        $vibe = VibeOption::findOrFail($id);

        $data = $request->validate([
            'emoji' => 'required',
            'label' => 'required',
            'message' => 'required',
            'eq_strategy' => 'nullable|string',
            'home_focus' => 'nullable|string',
            'active' => 'boolean',
        ]);

        $vibe->update($data);
        return redirect()->route('admin.vibe_options.index')->with('success', 'Vibe updated');
    }

    public function destroy($id)
    {
        VibeOption::destroy($id);
        return redirect()->route('admin.vibe_options.index')->with('success', 'Vibe deleted');
    }
}
