<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Artist;

class ArtistControllernew extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $query = Artist::query();
            $totalData = $query->count();

            if ($search = $request->input('search.value')) {
                $query->where('name', 'LIKE', "%{$search}%");
            }

            $artists = $query->offset($request->input('start'))
                             ->limit($request->input('length'))
                             ->get();

            return response()->json([
                "draw" => intval($request->input('draw')),
                "recordsTotal" => $totalData,
                "recordsFiltered" => $totalData,
                "data" => $artists->map(function ($artist) {
                    return [
                        'name' => $artist->name ? : 'N/A',
                        'description' => $artist->description ? : 'N/A',
                        'background_info' => $artist->background_info ? : 'N/A',
                        'personality_traits' => $artist->personality_traits ? : 'N/A',
                        'appearance_details' => $artist->appearance_details ? : 'N/A',
                        'action' => '<button class="btn btn-success edit" data-id="' . $artist->id . '">Edit</button>
                                     <button class="btn btn-danger delete" data-id="' . $artist->id . '">Delete</button>',
                    ];
                }),
            ]);
        }

        return view('artists.index');
    }

    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => 'required|string|max:255',
            'description' => 'required|string',
            'background_info' => 'nullable|string',
            'personality_traits' => 'nullable|string',
            'appearance_details' => 'nullable|string',
        ]);

        Artist::create($data);

        return response()->json(['success' => true, 'message' => 'Artist added successfully.']);
    }

    public function edit($id)
    {
        $artist = Artist::find($id);

        if (!$artist) {
            return response()->json(['success' => false, 'message' => 'Artist not found'], 404);
        }

        return response()->json($artist);
    }

    public function update(Request $request)
    {
        $data = $request->validate([
            'id' => 'required|integer|exists:artists,id',
            'name' => 'required|string|max:255',
            'description' => 'required|string',
            'background_info' => 'nullable|string',
            'personality_traits' => 'nullable|string',
            'appearance_details' => 'nullable|string',
        ]);

        $artist = Artist::find($data['id']);
        $artist->update($data);

        return response()->json(['success' => true, 'message' => 'Artist updated successfully.']);
    }

    public function destroy(Request $request)
    {
        $id = $request->input('id');
        $artist = Artist::find($id);

        if (!$artist) {
            return response()->json(['success' => false, 'message' => 'Artist not found'], 404);
        }

        $artist->delete();

        return response()->json(['success' => true, 'message' => 'Artist deleted successfully.']);
    }
}
