<?php

namespace App\Http\Controllers;

use App\Models\Follower; // Import the Follower model
use App\Models\User;
use Illuminate\Http\Request;

class FollowerController extends Controller
{
   
    public function __construct()
    {
        $this->middleware('checkHeader');
    }
    public function countFollowersAndFollowing($userId)
{
    $followersCount = Follower::where('user_id', $userId)->count();
    $followingCount = Follower::where('follower_id', $userId)->count();

    return response()->json([
        'followers_count' => $followersCount,
        'following_count' => $followingCount,
    ], 200);
}

public function getFollowers($userId, Request $request)
{
    $followers = Follower::where('user_id', $userId)
        ->whereHas('follower') // Ensure follower exists
        ->with('follower') // Load follower data
        ->paginate(10);

    // Check if followers exist
    if ($followers->isEmpty()) {
        return response()->json([
            'status' => false,
            'message' => 'No followers found.',
            'data' => []
        ], 200);
    }

    return response()->json([
        'status' => true,
        'message' => 'Followers retrieved successfully.',
        'data' => $followers
    ], 200);
}

public function getFollowing($userId, Request $request)
{
    $following = Follower::where('follower_id', $userId)
        ->with('user') // Load followed user data
        ->paginate(10);

    return response()->json($following, 200);
}

public function addFollower(Request $request)
{
    $request->validate([
        'user_id' => 'required|exists:users,id',
        'follower_id' => 'required|exists:users,id',
    ]);

    // Prevent a user from following themselves
    if ($request->user_id === $request->follower_id) {
        return response()->json(['message' => 'A user cannot follow themselves'], 400);
    }

    // Check if the follower relationship already exists
    $exists = Follower::where('user_id', $request->user_id)
        ->where('follower_id', $request->follower_id)
        ->exists();

    if ($exists) {
        return response()->json(['message' => 'User is already a follower'], 400);
    }

    $follower = Follower::create([
        'user_id' => $request->user_id,
        'follower_id' => $request->follower_id,
    ]);

    return response()->json([
        'message' => 'Follower added successfully',
        'data' => $follower,
    ], 201);
}
public function removeFollower(Request $request)
{
    $request->validate([
        'user_id' => 'required|exists:users,id',
        'follower_id' => 'required|exists:users,id',
    ]);

    $deleted = Follower::where('user_id', $request->user_id)
        ->where('follower_id', $request->follower_id)
        ->delete();

    if ($deleted) {
        return response()->json(['message' => 'Follower removed successfully'], 200);
    } else {
        return response()->json(['message' => 'Follower relationship not found'], 404);
    }
}

public function checkFollowStatus($userId, $followerId)
{
    // Check if the follower relationship exists
    $isFollowing = Follower::where('user_id', $userId)
        ->where('follower_id', $followerId)
        ->exists();

    return response()->json([
        'status' => true,
        'message' => 'Follow status retrieved successfully.',
        'is_following' => $isFollowing,
    ], 200);
}

}
