<?php

namespace App\Http\Controllers;

use App\Models\HeadphoneAd;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class HeadphoneAdController extends Controller
{
    // GET /api/ads/headphones?user_id=123
    public function fetchAd(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id'
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
        }

        $user = User::find($request->user_id);

        // Only send ad if user does NOT have headphones
        if ($user->has_vukaya_headphones) {
            return response()->json([
                'status' => true,
                'show_ad' => false,
                'message' => 'User already has headphones'
            ]);
        }

        $ad = HeadphoneAd::where('active', true)->latest()->first();

        if (!$ad) {
            return response()->json(['status' => false, 'message' => 'No active ad available']);
        }

        return response()->json([
            'status' => true,
            'show_ad' => true,
            'data' => $ad
        ]);
    }

    // Admin method (optional): create/update ad
   public function createAd(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'title' => 'required|string',
            'description' => 'nullable|string',
            'image' => 'nullable|file|image|max:2048',
            'offer' => 'nullable|string',
            'link' => 'nullable|url',
            'active' => 'required|boolean',
        ]);

        if ($validator->fails()) {
            return GlobalFunction::sendSimpleResponse(false, $validator->errors()->first());
        }

        // 🟡 Upload to S3 using your utility
        $imagePath = null;
        if ($request->hasFile('image')) {
            $imagePath = GlobalFunction::uploadFilToS3($request, 'image');
        }

        $ad = HeadphoneAd::create([
            'title' => $request->title,
            'description' => $request->description,
            'image' => $imagePath,
            'offer' => $request->offer,
            'link' => $request->link,
            'active' => $request->active,
        ]);

        return GlobalFunction::sendDataResponse(true, 'Ad created successfully', $ad);
    }
    
}
