<?php

namespace App\Http\Controllers;

use App\Models\Profile;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class ProfileController extends Controller
{
    /**
     * GET /api/user/has-profile
     */
    public function hasProfile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
        }

        $hasProfile = Profile::where('user_id', $request->user_id)->exists();

        return response()->json([
            'status' => true,
            'has_profile' => $hasProfile
        ]);
    }

    /**
     * POST /api/user/profile
     */
    public function saveProfile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id',
            'cannabis_types' => 'nullable|array',
            'consumption_methods' => 'nullable|array',
            'usage_frequency' => 'nullable|string',
            'goals' => 'nullable|array',
            'preferred_effects' => 'nullable|array',
            'sound_preferences' => 'nullable|array',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
        }

        $profile = Profile::updateOrCreate(
            ['user_id' => $request->user_id],
            [
                'cannabis_types' => $request->cannabis_types,
                'consumption_methods' => $request->consumption_methods,
                'usage_frequency' => $request->usage_frequency,
                'goals' => $request->goals,
                'preferred_effects' => $request->preferred_effects,
                'sound_preferences' => $request->sound_preferences,
            ]
        );

        return response()->json([
            'status' => true,
            'message' => 'Profile saved successfully',
            'data' => $profile
        ]);
    }

    /**
     * GET /api/user/profile
     */
    public function getProfile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
        }

        $profile = Profile::where('user_id', $request->user_id)->first();

        if (!$profile) {
            return response()->json([
                'status' => false,
                'message' => 'Profile not found'
            ]);
        }

        return response()->json([
            'status' => true,
            'message' => 'Profile fetched successfully',
            'data' => $profile
        ]);
    }
}
