<?php

namespace App\Http\Controllers;

use App\Models\Sound;
use Illuminate\Http\Request;
use App\Models\Strain;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Exception;

class StrainController extends Controller
{
    public function addStrain(Request $request) {
    try {
        // Validate the request
        $validatedData = $request->validate([
            'user_id' => 'required|integer|exists:users,id',
            'strain_name' => 'required|string',
            'description' => 'required|string|max:2000',
        ]);

        // Ensure user_id is retrieved properly
        if (!$request->has('user_id') || empty($request->user_id)) {
            return response()->json([
                'status' => 400,
                'message' => 'User ID is required and cannot be null.'
            ], 400);
        }

        // Insert strain using Eloquent
        $strain = Strain::create([
            'user_id' => $request->user_id,
            'strain_name' => $request->strain_name,
            'description' => $request->description,
        ]);

        return response()->json([
            'status' => 200,
            'message' => 'Strain created successfully',
        ], 200);

    } catch (\Exception $e) {
        return response()->json([
            'status' => 500,
            'message' => 'Server Error',
            'error' => $e->getMessage()
        ], 500);
    }
}

    
    public function fetchAllStrain(Request $request) {
        $totalData = Strain::count();
        $rows = Strain::orderBy('id', 'DESC')
                  ->join('users', 'strain_requests.user_id', '=', 'users.id')
                  ->select('strain_requests.*', 'users.identity as email')
                  ->get();    
        $strains = $rows;
        
        // $columns = array(
        //     0 => 'id',
        // );
        
        // $limit = $request->input('length');
        // $start = $request->input('start');
        // $orderColumn = $columns[$request->input('order.0.column')];
        // $dir = $request->input('order.0.dir');
        // $totalFiltered = $totalData;
        // if (empty($request->input('search.value'))) {
        //     if ($limit == $start) {
        //         $limit += 10;
        //     }
        //     $strains = Strain::join('users', 'strain_requests.user_id', '=', 'users.id')
        //         ->select('users.identity as email', 'strain_requests.*')
        //         ->offset($start)
        //         ->limit($limit)
        //         ->orderBy("id", $dir)
        //         ->get();
        // } 
    
        $data = array();
        foreach ($strains as $strain) {
            $data[] = array(
                '<p>' . $strain->strain_name . '</p>',
                '<p>' . $strain->email . '</p>',
               '<span class="' . ($strain->status == 0 ? 'bg-danger' : 'bg-success') . ' px-2 py-1 rounded">' . ($strain->status == 0 ? 'Not Approved' : 'Approved') . '</span>',
                '<p>' . $strain->created_at . '</p>',
                '<button id="' . $strain->id . '" data-id="' . $strain->id . '"  class="btn btn-primary change_status"><i class="fas fa-edit"></i></button><button class="btn btn-danger ml-2 text-white delete_btn" data-id="' . $strain->id . '"><i class="fas fa-trash-alt"></i></button>',
            );
        }
    
        $json_data = array(
            "data" => $data,
            // "recordsTotal" => intval($totalData),
            // "recordsFiltered" => $totalFiltered,
        );
    
        echo json_encode($json_data);
    }
    
    
    public function searchStrains(Request $request)
{
    try {
        $query = $request->input('query'); // Get the search term from the request

        // Validate the query input
        $validator = Validator::make($request->all(), [
            'query' => 'required|string|max:255',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => 400, 'message' => 'Invalid search query', 'errors' => $validator->errors()]);
        }

        // Perform a wildcard search on the 'strain_name' and 'description' fields
        $strains = Strain::where('strain_name', 'LIKE', '%' . $query . '%')
            ->orWhere('description', 'LIKE', '%' . $query . '%')
            ->join('users', 'strain_requests.user_id', '=', 'users.id')
            ->select('strain_requests.*', 'users.identity as email')
            ->get();

        // Check if any strains were found
        if ($strains->isEmpty()) {
            return response()->json(['status' => 404, 'message' => 'No strains found matching the query']);
        }

        // Return the results
        return response()->json(['status' => 200, 'data' => $strains]);
    } catch (Exception $e) {
        // Handle exceptions
        return response()->json(['status' => 500, 'message' => 'Server Error', 'error' => $e->getMessage()]);
    }
}

    public function approveStatus($id) {
        $strain = Strain::findOrFail($id);
    
        $strain->status = ($strain->status == 0) ? 1 : 0;
    
        $strain->save();
    
        return response()->json(['status' => 200, 'message' => 'Status updated successfully']);
    }
    
   public function deleteStrain($id) {
        $strain = Strain::findOrFail($id);
        $strain->delete();
        
        return response()->json(['status' => 200, 'message' => 'Strain deleted successfully']);
    }

    
    
    
}
