<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Http\Response;

use App\Models\StrainType;

class StrainTypeController extends Controller
{
    public function store(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'eq' => 'required|string|max:255',
                'strain_type' => 'required|string|max:255',
            ]);

            $strainType = StrainType::create($validatedData);

            return response()->json([
                'message' => 'Strain Type created successfully',
                'data' => $strainType
            ], 200);
        } catch (\Exception $e) {
            Log::error('Error creating StrainType: ' . $e->getMessage());

            return response()->json([
                'message' => 'Failed to create Strain Type',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function index()
    {
        try {
            $strainTypes = StrainType::all();

            return response()->json([
                'message' => 'Strain Types retrieved successfully',
                'data' => $strainTypes
            ], 200);
        } catch (\Exception $e) {
            Log::error('Error fetching StrainTypes: ' . $e->getMessage());

            return response()->json([
                'message' => 'Failed to retrieve Strain Types',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function show($id)
    {
        try {
            $strainType = StrainType::find($id);

            if (!$strainType) {
                return response()->json([
                    'message' => 'Strain Type not found'
                ], 404);
            }

            return response()->json([
                'message' => 'Strain Type retrieved successfully',
                'data' => $strainType
            ], 200);
        } catch (\Exception $e) {
            Log::error('Error fetching StrainType: ' . $e->getMessage());

            return response()->json([
                'message' => 'Failed to retrieve Strain Type',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function update(Request $request, $id)
    {
        try {
            $strainType = StrainType::find($id);

            if (!$strainType) {
                return response()->json([
                    'message' => 'Strain Type not found'
                ], 404);
            }

            $validatedData = $request->validate([
                'eq' => 'required|string|max:255',
                'strain_type' => 'required|string|max:255',
            ]);

            $strainType->update($validatedData);

            return response()->json([
                'message' => 'Strain Type updated successfully',
                'data' => $strainType
            ], 200);
        } catch (\Exception $e) {
            Log::error('Error updating StrainType: ' . $e->getMessage());

            return response()->json([
                'message' => 'Failed to update Strain Type',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function destroy($id)
    {
        try {
            $strainType = StrainType::find($id);

            if (!$strainType) {
                return response()->json([
                    'message' => 'Strain Type not found'
                ], 404);
            }

            $strainType->delete();

            return response()->json([
                'message' => 'Strain Type deleted successfully'
            ], 200);
        } catch (\Exception $e) {
            Log::error('Error deleting StrainType: ' . $e->getMessage());

            return response()->json([
                'message' => 'Failed to delete Strain Type',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function indexnew()
    {
        $strainTypes = StrainType::all(); // Fetch all strain types
        return view('strain_types.index', compact('strainTypes'));
    }

    public function strainList(Request $request)
    {
        $totalData = StrainType::count();
        $rows = StrainType::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'image',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = StrainType::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = StrainType::Where('strain_types', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = StrainType::Where('strain_types', 'LIKE', "%{$search}%")->count();
        }
        $data = [];
        foreach ($result as $item) {

            $edit = '<a href="#" data-strain_type="' . $item->strain_types . '" data-eq="' . $item->eq . '" rel=' . $item->id . ' class="btn edit btn-success me-3">' . __('Edit') . '</a>';
            $delete = '<a href="#" class="btn delete btn-danger" rel=' . $item->id . '>' . __('Delete') . '</a>';
            $action = '<span class="float-end">' . $edit . $delete . ' </span>';

            $data[] = [
                $item->strain_types,
                $item->eq,
                $action
            ];
        }
        $json_data = [
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($totalData),
            'recordsFiltered' => $totalFiltered,
            'data' => $data,
        ];
        echo json_encode($json_data);
        exit();
    }


    public function addStrainTypes(Request $request)
    {
        $strain_types = new StrainType();
        $strain_types->strain_types = $request->strain_types;
        $strain_types->eq = $request->eq;

        $strain_types->save();

        return response()->json([
            'status' => true,
            'message' => 'strain_types Added Successfully',
            'data' => $strain_types,
        ]);
    }

    public function deleteStrainType(Request $request)
    {
        $strain_types = StrainType::where('id', $request->id)->first();

        if ($strain_types) {
            $strain_types->delete();

            return response()->json([
                'status' => true,
                'message' => 'Category Delete Successfully',
            ]);
        } else {
            return response()->json([
                'status' => true,
                'message' => 'Strian Type Deleted Successfully',
            ]);
        }
    }

    public function updateStrainType(Request $request)
    {

        $strain_types = StrainType::where('id', $request->id)->first();

        if ($strain_types == null) {
            return response()->json([
                'status' => false,
                'message' => 'StrainType Not Found',
            ]);
        } else {
            $strain_types->strain_types = $request->strain_types;
            $strain_types->eq = $request->eq;

            $strain_types->save();

            return response()->json([
                'status' => true,
                'message' => 'StrainType Updated Successfully',
            ]);
        }
    }
}
