<?php

namespace App\Http\Controllers;

use App\Models\GlobalFunction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class UserController extends Controller
{
    public function users()
    {
        return view('users');
    }

    public function usersList(Request $request)
    {
        $totalData = User::count();
        $rows = User::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'image',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = User::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = User::Where('identity', 'LIKE', "%{$search}%")
                ->orWhere('fullname', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = User::Where('identity', 'LIKE', "%{$search}%")
                                ->orWhere('fullname', 'LIKE', "%{$search}%")
                                ->count();
        }
        $data = [];
        foreach ($result as $item) {
  
            $imageUrl = GlobalFunction::createMediaUrl($item->image);

            if ($item->image != null) {
                $image = "<img src=". $imageUrl ." class='tbl_img'>";
            } else {
                $image = "<img src='./asset/img/placeholder-image.png' class='tbl_img'>";
            }
            if ($item->image == null) {
                $imageUrl = "null";
            }
 
            if ($item->device_type == 0) {
                $device_type = 'Android';
            } else {
                $device_type = 'iOS';
            }

            if ($item->login_type == 0) {
                $login_type = 'Google';
            } else if ($item->login_type == 1) {
                $login_type = 'Apple';
            } else {
                $login_type = 'Email';
            }

            
            $identity = '<div class="itemDescription">'. $item->identity .'</div>';
            $fullname = '<div class="itemDescription">'. $item->fullname .'</div>';

            $data[] = [   
                $image,           
                $identity,
                $fullname,
                $device_type,
                $login_type
            ];
        }
        $json_data = [
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($totalData),
            'recordsFiltered' => $totalFiltered,
            'data' => $data,
        ];
        echo json_encode($json_data);
        exit(); 
    }

    public function registerUser(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'identity' => 'required',
        ]);

         if ($validator->fails()) {
            $messages = $validator->errors()->all();
            $msg = $messages[0];
            return response()->json(['status' => false, 'message' => $msg]);
        }


        $user = User::where('identity', $request->identity)->first();

        if ($user ) {

            $user->login_type = (int) $request->login_type;
            $user->device_type = (int) $request->device_type;
            $user->device_token = $request->device_token;
            $user->save();

            return response()->json([
                'status' => true,
                'message' => 'User is already exist',
                'data' => $user,
            ]);
        }
        
        $user = new User();
        $user->identity = $request->identity;
        $user->fullname = $request->fullname;
        $user->login_type = (int) $request->login_type;
        $user->device_type = (int) $request->device_type;
        $user->device_token = $request->device_token;
        $user->save();

        return response()->json([
            'status' => true,
            'message' => 'User Added Successfully',
            'data' => $user,
        ]);

    }
 
    public function editProfile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required',
        ]);

        if ($validator->fails()) {
            $messages = $validator->errors()->all();
            $msg = $messages[0];
            return response()->json(['status' => false, 'message' => $msg]);
        }

        $user = User::where('id', $request->user_id)->first();
        if ($user) { 
            if ($request->has('fullname')) {
                $user->fullname = $request->fullname;
            }
            if ($request->has('liked_music_ids')) {
                $user->liked_music_ids = $request->liked_music_ids;
            }
            if ($request->hasFile('image')) {
                $path = GlobalFunction::deleteFile($user->image);
                $file = $request->file('image');
                $path = GlobalFunction::saveFileAndGivePath($file, "users-images");
                $user->image = $path;
            }
            $user->save();

            return response()->json([
                'status' => true,
                'message' => 'User Updated Successfully',
                'data' => $user,
            ]);
        } else {
            return response()->json([
                'status' => false,
                'message' => 'User Not Found',
            ]);
        }
    }

    public function deleteMyAccount(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required',
        ]);

         if ($validator->fails()) {
            $messages = $validator->errors()->all();
            $msg = $messages[0];
            return response()->json(['status' => false, 'message' => $msg]);
        }


        $user = User::where('id', $request->user_id)->first();
        if ($user) {
             
            GlobalFunction::deleteFile($user->image);
            $user->delete();
        
            return response()->json([
                'status' => true,
                'message' => 'User Account deleted successfully'
            ]);
        } 
        return response()->json([
            'status' => false,
            'message' => 'User not found',
        ]);
    }

  public function fetchUserProfile(Request $request)
{
    $validator = Validator::make($request->all(), [
        'user_id' => 'nullable|integer',
        'fullname' => 'nullable|string',
    ]);

    if ($validator->fails()) {
        $messages = $validator->errors()->all();
        $msg = $messages[0];
        return response()->json(['status' => false, 'message' => $msg]);
    }

    // Ensure at least one parameter is provided
    if (!$request->has('user_id') && !$request->has('fullname')) {
        return response()->json([
            'status' => false,
            'message' => 'Either user_id or fullname is required.',
        ], 400);
    }

    // Fetch user by user_id or fullname
    $user = null;
    if ($request->has('user_id')) {
        $user = User::where('id', $request->user_id)->first();
    } elseif ($request->has('fullname')) {
        $user = User::where('fullname', 'LIKE', "%{$request->fullname}%")->first();
    }

    if ($user) {
        return response()->json([
            'status' => true,
            'message' => 'Fetch user profile detail successfully',
            'data' => $user,
        ]);
    }

    return response()->json([
        'status' => false,
        'message' => 'User not found',
    ]);
}


    public function logout(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required',
        ]);

        if ($validator->fails()) {
            $messages = $validator->errors()->all();
            $msg = $messages[0];
            return response()->json(['status' => false, 'message' => $msg]);
        }

        $user = User::where('id', $request->user_id)->first();
        if ($user) {
            $user->device_token = null;
            $user->save();
            return response()->json([
                'status' => true,
                'message' => 'User logout successfully'
            ]);
        } 
        return response()->json([
            'status' => false,
            'message' => 'User not found',
        ]);
    }


public function hasHeadphones(Request $request)
{
    $validator = Validator::make($request->all(), [
        'user_id' => 'required|exists:users,id',
    ]);

    if ($validator->fails()) {
        return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
    }

    $user = User::find($request->user_id);

    return response()->json([
        'status' => true,
        'has_headphones' => (bool) $user->has_vukaya_headphones,
    ]);
}

public function updateHeadphones(Request $request)
{
    $validator = Validator::make($request->all(), [
        'user_id' => 'required|exists:users,id',
        'has_headphones' => 'required|boolean',
    ]);

    if ($validator->fails()) {
        return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
    }

    $user = User::find($request->user_id);
    $user->has_vukaya_headphones = $request->has_headphones;
    $user->save();

    return response()->json([
        'status' => true,
        'message' => 'Headphone ownership updated',
        'has_headphones' => $user->has_vukaya_headphones
    ]);
}

public function getPaginatedUsers(Request $request)
{
    $searchTerm = $request->input('search', '');

    $usersQuery = User::query();

    // If search term is not empty, filter users by search term
    if (!empty($searchTerm)) {
        $usersQuery->where('identity', 'LIKE', "%{$searchTerm}%")
            ->orWhere('fullname', 'LIKE', "%{$searchTerm}%");
    } else {
        // If search term is empty, get random users
        $usersQuery->inRandomOrder();
    }

    // Paginate results (20 users per page)
    $users = $usersQuery->paginate(20);

    // Check if any users exist
    if ($users->isEmpty()) {
        return response()->json([
            'status' => true,
            'message' => 'No users found.',
            'data' => [],
        ], 200);
    }

    // Map users to only include required fields
    $userData = $users->map(function ($user) {
        return [
            'id' => $user->id,
            'identity' => $user->identity,
            'fullname' => $user->fullname,
            'image' => $user->image ? $user->image : null,
        ];
    });

    return response()->json([
        'status' => true,
        'message' => 'Users fetched successfully.',
        'data' => $userData,
    ], 200);
}

}
