<?php

namespace App\Models;

use Google\Client;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;

class GlobalFunction extends Model
{
    use HasFactory;

    public static function sendSimpleResponse($status, $msg)
    {
        return response()->json(['status' => $status, 'message' => $msg]);
    }
    public static function sendDataResponse($status, $msg, $data)
    {
        return response()->json(['status' => $status, 'message' => $msg, 'data' => $data]);
    }

 public static function sendPushNotificationToAllUsers($title, $message)
{
    $client = new Client();
    $client->setAuthConfig(base_path('googleCredentials.json'));
    $client->addScope('https://www.googleapis.com/auth/firebase.messaging');
    $client->fetchAccessTokenWithAssertion();
    $accessToken = $client->getAccessToken()['access_token'];

    $url = 'https://fcm.googleapis.com/v1/projects/YOUR_PROJECT_ID/messages:send';
    
    $fields = [
        'message' => [
            'topic' => 'Vukaya',
            'notification' => [
                'title' => $title,
                'body' => $message,
            ],
            'data' => [
                'click_action' => 'FLUTTER_NOTIFICATION_CLICK',
                'message' => $message
            ],
            'android' => [
                'priority' => 'high',
                'notification' => [
                    'sound' => 'default',
                ],
            ],
            'apns' => [
                'payload' => [
                    'aps' => [
                        'sound' => 'default'
                    ]
                ]
            ]
        ]
    ];

    $headers = [
        'Content-Type: application/json',
        'Authorization: Bearer ' . $accessToken
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));
    
    $result = curl_exec($ch);
    curl_close($ch);

    if ($result === FALSE) {
        \Log::error('FCM Send Error: ' . curl_error($ch));
        return json_encode(['status' => false, 'message' => 'Failed to send push notification']);
    }

    return json_encode(['status' => true, 'message' => 'Notification sent successfully', 'response' => json_decode($result, true)]);
}


    public static function createMediaUrl($media)
{
    if (!$media || !is_string($media)) {
        return null;
    }

    try {
        return Storage::disk('s3')->url($media);
    } catch (\Exception $e) {
        \Log::error('Failed to get S3 media URL: ' . $e->getMessage());
        return null;
    }
}
    public static function uploadFilToS3($request, $key)
    {
        $s3 = Storage::disk('s3');
        $file = $request->file($key);
        $fileName = time() . $file->getClientOriginalName();
        $fileName = str_replace(" ", "_", $fileName);
        $filePath = 'uploads/' . $fileName;
        $result =  $s3->put($filePath, file_get_contents($file), 'public-read');
        return $filePath;
    }

    public static function point2point_distance($lat1, $lon1, $lat2, $lon2, $unit = 'K', $radius)
    {
        $theta = $lon1 - $lon2;
        $dist = sin(deg2rad($lat1)) * sin(deg2rad($lat2)) +  cos(deg2rad($lat1)) * cos(deg2rad($lat2)) * cos(deg2rad($theta));
        $dist = acos($dist);
        $dist = rad2deg($dist);
        $miles = $dist * 60 * 1.1515;
        $unit = strtoupper($unit);

        if ($unit == "K") {
            return (($miles * 1.609344) <= $radius);
        } else if ($unit == "N") {
            return ($miles * 0.8684);
        } else {
            return $miles;
        }
    }
public static function uploadNarrationFromBinary($binary)
{
    $tempPath = storage_path('app/temp_' . uniqid() . '.mp3');
    file_put_contents($tempPath, $binary);

    if (!file_exists($tempPath)) {
        \Log::error("Narration upload: Failed to write temp file: $tempPath");
        return null;
    }

    $file = new \Illuminate\Http\File($tempPath);

    $filename = 'narration_' . uniqid() . '.mp3';
    $s3Path = 'uploads/narrations/' . $filename;

    try {
        $result = Storage::disk('s3')->putFileAs(
            'uploads/narrations',
            $file,
            $filename,
            ['visibility' => 'public', 'ContentType' => 'audio/mpeg']
        );

        // Optional check
        if (!Storage::disk('s3')->exists($s3Path)) {
            \Log::error("❌ Upload failed or file not found immediately after upload: $s3Path");
            return null;
        }

        @unlink($tempPath); // cleanup
        return Storage::disk('s3')->url($s3Path);

    } catch (\Exception $e) {
        \Log::error("❌ Exception during S3 upload: " . $e->getMessage());
        return null;
    }
}



    public static function cleanString($string)
    {
        return  str_replace(array('<', '>', '{', '}', '[', ']', '`'), '', $string);
    }

   public static function deleteFile($filename)
{
    if (!empty($filename) && is_string($filename)) {
        try {
            Storage::disk('s3')->delete($filename);
        } catch (\Exception $e) {
            \Log::error('Error deleting file from S3: ' . $e->getMessage());
        }
    }
}

    public static function saveFileAndGivePath($file, $folder = '')
    {
        if ($file != null) {
            if ($folder != '') {
                $path = $file->store("uploads/$folder");
            } else {
                $path = $file->store('uploads');
            }
            return $path;
        } else {
            return null;
        }
    }
}
