<?
namespace App\Services;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use App\Models\Narration;
use Illuminate\Support\Facades\Log;
use App\Models\GlobalFunction;
use Illuminate\Http\UploadedFile;

class NarrationService
{
    public static function generate($type, $params = [])
{
    $prompt = self::buildPrompt($type, $params);
    if (!$prompt) return null;

    // Step 1: Generate script
    $text = self::generateScript($prompt);
    if (!$text) return null;

    // Step 2: Generate audio
    $audioBinary = self::textToSpeech($text);
    if (!$audioBinary) return null;

    // Step 3: Save binary to temp file
    $tempPath = storage_path('app/temp_' . uniqid() . '.mp3');
    file_put_contents($tempPath, $audioBinary);

    // Step 4: Convert to fake UploadedFile
    $uploadedFile = new UploadedFile(
        $tempPath,
        'narration.mp3',
        'audio/mpeg',
        null,
        true // $testMode = true, since this isn't an actual HTTP upload
    );

    // Step 5: Upload just like admin view
    $path = $uploadedFile->store('uploads/narrations', 's3');
    @unlink($tempPath); // cleanup

    return Storage::disk('s3')->url($path);
}

 protected static function buildPrompt($type, $params)
{
    return match ($type) {
        'intro' =>
            "You're narrating the start of a personalized wellness session for {$params['user_name']}. " .
            "Welcome them warmly, introduce the session titled '{$params['session_title']}', designed for the {$params['time_tag']} with a {$params['vibe']} feel. inform the session is sonically tuned to cannabis strain profile '{$params['cannabis_tag']} and experienced best on Vukaya headphones. " .
            "Wrap up the intro by setting the stage for the first track: '{$params['first_track_title']}' — be brief but atmospheric. Keep total output under 60 words.",

        'music' =>
            "Create a 1-sentence spoken intro (under 30 words) for the next music track titled '{$params['track_title']}', tagged with {$params['tags']}. " .
            "Mention that it's coming after '{$params['previous_track_title']}' to create flow. checkin, see how they are enjoying the session or song. Maintain a warm, calming tone.",

        'podcast' =>
            "You're introducing the podcast '{$params['title']}' with this summary: {$params['description']}. Keep it under 35 words, natural, and inviting.",

        'outro' =>
            "You're wrapping up the session '{$params['session_title']}' for {$params['user_name']}. Thank them warmly. " .
            "Encourage a moment of reflection, and invite them to share feedback in the app. Limit to 25–30 words.",

        default => null,
    };
}

   protected static function generateScript($prompt)
{
    $response = Http::withToken(env('OPENAI_API_KEY'))
        ->post('https://api.openai.com/v1/chat/completions', [
            'model' => 'gpt-4',
            'messages' => [
                ['role' => 'system', 'content' => 'You are a friendly and engaging voice narrator.'],
                ['role' => 'user', 'content' => $prompt],
            ],
            'max_tokens' => 150,
            'temperature' => 0.8,
        ]);

    \Log::info('OpenAI Response', $response->json());

    return $response->json('choices.0.message.content') ?? null;
}

   protected static function textToSpeech($text)
{
    \Log::info('Sending to ElevenLabs TTS', ['text' => $text]);

    $response = Http::withHeaders([
        'xi-api-key' => env('ELEVENLABS_API_KEY'),
        'Accept' => 'audio/mpeg',
        'Content-Type' => 'application/json',
    ])->post("https://api.elevenlabs.io/v1/text-to-speech/" . env('ELEVENLABS_VOICE_ID'), [
        'text' => $text,
        'voice_settings' => [
            'stability' => 0.5,
            'similarity_boost' => 0.7
        ]
    ]);

    \Log::info('ElevenLabs Status: ' . $response->status());

    if ($response->successful()) {
        return $response->body();
    }

    \Log::error('ElevenLabs Error', ['body' => $response->body()]);
    return null;
}

}