<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\ActivityBlueprint;

class ActivityBlueprintSeeder extends Seeder
{
    public function run()
    {
        $blueprints = [
            [
                'trigger_tag' => 'focus',
                'title' => 'Clarity Flow',
                'description' => 'Boost mental sharpness with bright tones and low distraction.',
                'default_duration' => 360,
                'default_tags' => ['binaural', 'alpha waves', 'lo-fi', 'ambient synth'],
                'eq_profile' => [2, 3, 3, 2, 1, 1, 0, 0, 0, 1],
            ],
            [
                'trigger_tag' => 'calm',
                'title' => 'Ease In',
                'description' => 'Gently shift into grounded presence.',
                'default_duration' => 300,
                'default_tags' => ['warm mids', 'rain', 'piano ambient', 'theta waves'],
                'eq_profile' => [1, 2, 2, 1, 1, 1, 0, 0, 0, 0],
            ],
            [
                'trigger_tag' => 'sleep',
                'title' => 'Float Down',
                'description' => 'Support letting go with sub-bass and slow ambient textures.',
                'default_duration' => 480,
                'default_tags' => ['delta waves', 'white noise', 'vapor trails', 'deep drones'],
                'eq_profile' => [0, 1, 1, 1, 1, 0, 0, 0, 0, 0],
            ],
            [
                'trigger_tag' => 'creative',
                'title' => 'Creative Pulse',
                'description' => 'Activate imagination with rhythmic layers.',
                'default_duration' => 420,
                'default_tags' => ['future beats', 'modular loops', 'jazzy house'],
                'eq_profile' => [1, 2, 3, 3, 2, 1, 1, 1, 0, 0],
            ],
            [
                'trigger_tag' => 'stillness',
                'title' => 'Anchor In',
                'description' => 'Deep centering through pure tones and silence layers.',
                'default_duration' => 600,
                'default_tags' => ['binaural', 'sacred geometry', 'field recordings'],
                'eq_profile' => [0, 0, 1, 1, 1, 0, 0, 0, 0, 0],
            ],
            [
                'trigger_tag' => 'movement',
                'title' => 'Body Flow',
                'description' => 'Sync movement with breath and rhythm.',
                'default_duration' => 360,
                'default_tags' => ['rhythmic ambient', 'electro-tango', 'lo-fi funk'],
                'eq_profile' => [2, 2, 2, 2, 1, 1, 1, 1, 1, 0],
            ],
        ];

        foreach ($blueprints as $bp) {
            ActivityBlueprint::create([
                'trigger_tag' => $bp['trigger_tag'],
                'title' => $bp['title'],
                'description' => $bp['description'],
                'default_duration' => $bp['default_duration'],
                'default_tags' => $bp['default_tags'],
                'eq_profile' => $bp['eq_profile'],
                'active' => true,
            ]);
        }
    }
}
