<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\GuidedSession;
use App\Models\SessionActivity;
use App\Models\Music;
use App\Models\Podcast;

class GuidedSessionSeeder extends Seeder
{
    public function run()
    {
        // 🌀 Session 1: Morning Chill
        $session1 = GuidedSession::create([
            'title' => 'Morning Chill Reset',
            'description' => 'Ease into the day with calm focus and layered soundscapes.',
            'base_duration' => 900,
            'active' => true,
        ]);

        $activity1 = SessionActivity::create([
            'guided_session_id' => $session1->id,
            'title' => 'Breathe and Begin',
            'description' => 'Simple breath-focused warm-up.',
            'duration' => 180,
            'eq_profile' => json_encode([1, 2, 1, 0, 0, 0, 1, 2, 2, 1]),
            'tag_filters' => json_encode(['chill', 'morning', 'hybrid']),
        ]);

        $activity2 = SessionActivity::create([
            'guided_session_id' => $session1->id,
            'title' => 'Clarity Flow',
            'description' => 'Enhance alertness with soft beats and ambient pads.',
            'duration' => 420,
            'eq_profile' => json_encode([2, 2, 1, 0, 1, 1, 2, 2, 1, 0]),
            'tag_filters' => json_encode(['focus', 'ambient', 'morning']),
        ]);

        $music = Music::where('tag', 'like', '%morning%')->first();
        $podcast = Podcast::where('description', 'like', '%calm%')->first();

        if ($music) $activity1->musicTracks()->attach($music->id);
        if ($podcast) $activity2->podcasts()->attach($podcast->id);

        // 🔥 Session 2: Evening Wind Down
        $session2 = GuidedSession::create([
            'title' => 'Evening Wind Down',
            'description' => 'Let go of the day with slow textures and introspection.',
            'base_duration' => 1080,
            'active' => true,
        ]);

        $activity3 = SessionActivity::create([
            'guided_session_id' => $session2->id,
            'title' => 'Release the Tension',
            'description' => 'Deep tones to help you exhale the day.',
            'duration' => 360,
            'eq_profile' => json_encode([0, 1, 2, 2, 2, 1, 0, 0, 0, 1]),
            'tag_filters' => json_encode(['lowkey', 'night', 'indica']),
        ]);

        $activity4 = SessionActivity::create([
            'guided_session_id' => $session2->id,
            'title' => 'Reflective Drift',
            'description' => 'Space to journal or just float mentally.',
            'duration' => 720,
            'eq_profile' => json_encode([1, 1, 2, 2, 1, 0, 0, 1, 2, 2]),
            'tag_filters' => json_encode(['chill', 'night', 'reflect']),
        ]);

        $music2 = Music::where('tag', 'like', '%night%')->first();
        $podcast2 = Podcast::where('description', 'like', '%relax%')->first();

        if ($music2) $activity3->musicTracks()->attach($music2->id);
        if ($podcast2) $activity4->podcasts()->attach($podcast2->id);
    }
}
