<?php
namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\GuidedSessionTemplate;

class GuidedSessionTemplateSeeder extends Seeder
{
    public function run()
    {
        $sessions = [
            [
                'title' => 'Morning Focus – Clear Start',
                'description' => 'Start the day with clarity and momentum.',
                'goal_tags' => ['morning', 'focus'],
                'mood_tags' => ['clarity', 'motivation', 'focus', 'awaken', 'energized'],
                'sound_tags' => ['bright', 'lo-fi', 'clean highs', 'alpha waves', 'neo-soul', 'mid-tempo'],
                'cannabis_tags' => ['sativa', 'green crack', 'durban poison'],
                'use_case_tags' => ['morning ritual', 'brain fog', 'work start'],
                'time_of_day' => 'morning',
                'icon' => '🌞'
            ],
            [
                'title' => 'Anxiety Reduction – Calm Reset',
                'description' => 'Soothing support for an overwhelmed mind.',
                'goal_tags' => ['calm', 'reset'],
                'mood_tags' => ['grounded', 'safe', 'gentle', 'tension relief'],
                'sound_tags' => ['warm mids', 'theta waves', 'rain sounds', 'piano ambient'],
                'cannabis_tags' => ['high-CBD', 'harlequin', 'cannatonic'],
                'use_case_tags' => ['decompress', 'mental reset', 'overwhelm'],
                'time_of_day' => 'any',
                'icon' => '🌿'
            ],
            [
                'title' => 'Creative Activation – Creative Spark',
                'description' => 'Fuel imagination and creative energy.',
                'goal_tags' => ['creative', 'flow'],
                'mood_tags' => ['inspired', 'playful', 'imaginative'],
                'sound_tags' => ['high sparkle', 'future beats', 'modular loops', 'jazzy house'],
                'cannabis_tags' => ['sativa', 'jack herer', 'blue dream'],
                'use_case_tags' => ['brainstorming', 'art-making', 'flow state'],
                'time_of_day' => 'afternoon',
                'icon' => '🔥'
            ],
            [
                'title' => 'Emotional Recovery – Heart Space',
                'description' => 'Supportive space for healing and reflection.',
                'goal_tags' => ['healing', 'recovery'],
                'mood_tags' => ['grief', 'vulnerability', 'tenderness'],
                'sound_tags' => ['minimal piano', 'healing drones', 'ambient folk'],
                'cannabis_tags' => ['indica', 'blue cheese', 'G13'],
                'use_case_tags' => ['journaling', 'solo time', 'emotional processing'],
                'time_of_day' => 'evening',
                'icon' => '🌧️'
            ],
            [
                'title' => 'Meditative Stillness – Deep Still',
                'description' => 'Minimalism and space for deep silence.',
                'goal_tags' => ['meditation', 'stillness'],
                'mood_tags' => ['present', 'centered', 'clean mind'],
                'sound_tags' => ['binaural beats', 'pure tones', 'field recordings'],
                'cannabis_tags' => ['none', 'light-CBD'],
                'use_case_tags' => ['breathwork', 'inner stillness', 'silence training'],
                'time_of_day' => 'any',
                'icon' => '🧘'
            ],
            [
                'title' => 'Movement & Flow – Body Flow',
                'description' => 'Move with intention and body-mind sync.',
                'goal_tags' => ['movement', 'flow'],
                'mood_tags' => ['fluidity', 'alignment', 'dynamic calm'],
                'sound_tags' => ['rhythmic ambient', 'instrumental funk', 'electro-tango'],
                'cannabis_tags' => ['hybrid-balanced', 'pineapple express'],
                'use_case_tags' => ['yoga', 'walking', 'somatic work'],
                'time_of_day' => 'afternoon',
                'icon' => '🚶‍♀️'
            ],
            [
                'title' => 'Evening Calm – Wind Down',
                'description' => 'Let go of the day with warmth and softness.',
                'goal_tags' => ['evening calm', 'unwind'],
                'mood_tags' => ['relaxed', 'peace', 'cozy'],
                'sound_tags' => ['lush textures', 'ambient soul', 'dreamy pads'],
                'cannabis_tags' => ['indica', 'purple kush', 'granddaddy purple'],
                'use_case_tags' => ['tea time', 'reading', 'bed prep'],
                'time_of_day' => 'evening',
                'icon' => '🌃'
            ],
            [
                'title' => 'Sleep Aid – Sleep Drift',
                'description' => 'Support for deep rest and letting go.',
                'goal_tags' => ['sleep', 'stillness'],
                'mood_tags' => ['surrender', 'drift', 'dreamlike'],
                'sound_tags' => ['sub-bass', 'delta waves', 'white noise', '432Hz music'],
                'cannabis_tags' => ['heavy indica', '9 pound hammer'],
                'use_case_tags' => ['bedtime', 'insomnia'],
                'time_of_day' => 'night',
                'icon' => '💤'
            ],
            [
                'title' => 'Mood Uplift – Mood Lift',
                'description' => 'Joyful boost to elevate your energy.',
                'goal_tags' => ['mood lift', 'joy'],
                'mood_tags' => ['cheerful', 'sociable', 'feel-good'],
                'sound_tags' => ['electro-funk', 'bossa nova', 'jazzy house'],
                'cannabis_tags' => ['uplifting sativa', 'pineapple express'],
                'use_case_tags' => ['social prep', 'energy break'],
                'time_of_day' => 'early evening',
                'icon' => '🌈'
            ],
            [
                'title' => 'Digital Detox – Off Grid',
                'description' => 'Step away from the screen and reset your senses.',
                'goal_tags' => ['tech burnout', 'sensory reset'],
                'mood_tags' => ['disconnected', 'clean', 'quietude'],
                'sound_tags' => ['nature sounds', 'analog tape', 'deep earth tones'],
                'cannabis_tags' => ['CBD-only', 'harle-tsu'],
                'use_case_tags' => ['post-screen', 'mindful unwind'],
                'time_of_day' => 'any',
                'icon' => '📵'
            ],
        ];

        foreach ($sessions as $session) {
            GuidedSessionTemplate::create($session);
        }
    }
}
