$(document).ready(function () {
    $(".sideBarli").removeClass("activeLi");
    $(".ArtistsSideA").addClass("activeLi");
    var selectedArtistID = 0;

    // Initialize DataTable
    $("#artistsTable").dataTable({
        processing: true,
        serverSide: true,
        language: {
            paginate: {
                next: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="9 18 15 12 9 6"></polyline></svg>',
                previous: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="15 18 9 12 15 6"></polyline></svg>',
            },
        },
        ajax: {
            url: "/artistList",
            type: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
        },
       columns: [
            { data: "name", name: "name" },
            { data: "image", name: "image" }, // Image column now just displays the URL
            { data: "description", name: "description" },
            { data: "background_info", name: "background_info" },
            { data: "personality_traits", name: "personality_traits" },
            { data: "appearance_details", name: "appearance_details" },
            { data: "action", name: "action", orderable: false, searchable: false },
        ],
    });

    // Add Artist
    $(document).on("submit", "#addArtistForm", function (e) {
        e.preventDefault();
        let formData = new FormData(this);

        $.ajax({
            type: "POST",
            url: "/storeArtist",
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.success) {
                    iziToast.show({
                        title: "Success",
                        message: "Artist Added Successfully",
                        color: "green",
                        position: "topRight",
                        timeout: 3000,
                    });
                    $("#artistsTable").DataTable().ajax.reload();
                    $("#artistModal").modal("hide");
                }
            },
        });
    });

    // Edit Artist
    $("#artistsTable").on("click", ".edit", function () {
        let id = $(this).data("id");

        $.get(`/artist/${id}/edit`, function (response) {
            if (response) {
                $("#edit_name").val(response.name);
                $("#edit_description").val(response.description);
                $("#edit_background_info").val(response.background_info);
                $("#edit_personality_traits").val(response.personality_traits);
                $("#edit_appearance_details").val(response.appearance_details);

                // Populate the image preview
                if (response.image) {
                    $("#currentImage").attr("src", response.image).show();
                } else {
                    $("#currentImage").hide(); // Hide the image if not available
                }

                selectedArtistID = id;
                $("#editArtistModal").modal("show");
            }
        });
    });

    // Update Artist
    $(document).on("submit", "#editArtistForm", function (e) {
        e.preventDefault();
        let formData = new FormData(this);
        formData.append("id", selectedArtistID);

        $.ajax({
            type: "POST",
            url: `/updateArtist`,
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.success) {
                    iziToast.show({
                        title: "Success",
                        message: "Artist Updated Successfully",
                        color: "green",
                        position: "topRight",
                        timeout: 3000,
                    });
                    $("#artistsTable").DataTable().ajax.reload();
                    $("#editArtistModal").modal("hide");
                }
            },
        });
    });

    // Delete Artist
    $("#artistsTable").on("click", ".delete", function () {
        let id = $(this).data("id");

        swal({
            title: "Are you sure?",
            text: "You are about to delete this artist.",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((willDelete) => {
            if (willDelete) {
                $.ajax({
                    type: "POST",
                    url: "/destroyArtist",
                    data: { id: id, _token: $('meta[name="csrf-token"]').attr("content") },
                    success: function (response) {
                        if (response.success) {
                            iziToast.show({
                                title: "Deleted",
                                message: "Artist Deleted Successfully",
                                color: "green",
                                position: "topRight",
                                timeout: 3000,
                            });
                            $("#artistsTable").DataTable().ajax.reload();
                        }
                    },
                });
            }
        });
    });
});
