$(document).ready(function () {
    $(".sideBarli").removeClass("activeLi");
    $(".eqcommentsSideA").addClass("activeLi");

    var selectedCommentID = 0;
    $("#commentsTable").dataTable({
        processing: true,
        serverSide: true,
        serverMethod: "post",
        aaSorting: [[0, "desc"]],
        language: {
            paginate: {
                next: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="9 18 15 12 9 6"></polyline></svg>',
                previous: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="15 18 9 12 15 6"></polyline></svg>',
            },
        },
        columnDefs: [
            {
                targets: [4],
                orderable: false,
            },
        ],
        ajax: {
            url: `${domainUrl}commentList`,
            error: (error) => {
                console.log(error);
            },
        },
        columns: [
            { data: "user" },   
            { data: "strain" }, 
            { data: "comment" }, 
            { data: "likes" },  
            { data: "action" },  
        ],    
    });

    // Add Comment
    $(document).on("submit", "#addCommentForm", function (e) {
        e.preventDefault();
        let formData = new FormData(this);

        swal({
            title: "Are you sure?",
            text: "You are about to add a new comment.",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((willAdd) => {
            if (willAdd) {
                $.ajax({
                    type: "POST",
                    url: "/storeComment",
                    data: formData,
                    contentType: false,
                    processData: false,
                    success: function (response) {
                        if (response.status) {
                            iziToast.show({
                                title: "Success",
                                message: "Comment Added Successfully",
                                color: "green",
                                position: "topRight",
                                timeout: 3000,
                            });
                            $("#commentsTable").DataTable().ajax.reload(null, false);
                            $("#commentModal").modal("hide");
                        } else {
                            iziToast.show({
                                title: "Error",
                                message: response.message,
                                color: "red",
                                position: "topRight",
                                timeout: 3000,
                            });
                        }
                    },
                });
            }
        });
    });

    // Edit Comment
    $("#commentsTable").on("click", ".edit", function (e) {
        e.preventDefault();
        var id = $(this).data("id");

        $.get(`/comment/${id}/edit`, function (response) {
            if (response.status) {
                // Set the current values for User, Strain, and Comment
                $("#editUserID").val(response.comment.user.id);
                $("#editStrainID").val(response.comment.strain.id);
                $("#editCommentText").val(response.comment.comment);
                selectedCommentID = id;
                $("#editCommentModal").modal("show");
            } else {
                iziToast.show({
                    title: "Error",
                    message: "Comment not found",
                    color: "red",
                    position: "topRight",
                    timeout: 3000,
                });
            }
        });
    });

    // Update Comment
    $(document).on("submit", "#editCommentForm", function (e) {
        e.preventDefault();
        let editformData = new FormData(this);
        editformData.append("id", selectedCommentID);

        swal({
            title: "Are you sure?",
            text: "You are about to update this comment.",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((willUpdate) => {
            if (willUpdate) {
                $.ajax({
                    type: "POST",
                    url: "/updateComment",
                    data: editformData,
                    contentType: false,
                    processData: false,
                    success: function (response) {
                        if (response.status) {
                            iziToast.show({
                                title: "Success",
                                message: "Comment Updated Successfully",
                                color: "green",
                                position: "topRight",
                                timeout: 3000,
                            });
                            $("#commentsTable").DataTable().ajax.reload(null, false);
                            $("#editCommentModal").modal("hide");
                        } else {
                            iziToast.show({
                                title: "Error",
                                message: "Failed to update comment",
                                color: "red",
                                position: "topRight",
                                timeout: 3000,
                            });
                        }
                    },
                });
            }
        });
    });


    // Delete Comment
    $("#commentsTable").on("click", ".delete", function (e) {
        e.preventDefault();
        var id = $(this).data("id");

        swal({
            title: "Are you sure?",
            text: "This action will delete the comment permanently.",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((willDelete) => {
            if (willDelete) {
                $.ajax({
                    type: "POST",
                    url: "/destroyComment",
                    data: {
                        id: id,
                        _token: $('meta[name="csrf-token"]').attr("content"),
                    },
                    success: function (response) {
                        if (response.status) {
                            iziToast.show({
                                title: "Deleted",
                                message: "Comment Deleted Successfully",
                                color: "green",
                                position: "topRight",
                                timeout: 3000,
                            });
                            $("#commentsTable").DataTable().ajax.reload(null, false);
                        } else {
                            iziToast.show({
                                title: "Error",
                                message: response.message,
                                color: "red",
                                position: "topRight",
                                timeout: 3000,
                            });
                        }
                    },
                });
            }
        });
    });
});
