$(document).ready(function () { 
    $(".sideBarli").removeClass("activeLi");
    $(".GenresSideA").addClass("activeLi");

    var selectedGenreID = 0;

    // 1) Initialize DataTable
    $("#genresTable").dataTable({
        processing: true,
        serverSide: true,
        language: {
            paginate: {
                next: '<svg ...>...</svg>',
                previous: '<svg ...>...</svg>',
            },
        },
        ajax: {
            url: "/genreList",
            type: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
        },
        columns: [
            { data: "name",        name: "name" },
            { data: "description", name: "description" },
            { data: "parent",      name: "parent" },
            // If you want to display 'type' in the table, add:
            { data: "type",     name: "type" },
            { data: "action",      name: "action", orderable: false, searchable: false },
        ],
    });

    // 2) Add Genre
    $(document).on("submit", "#addGenreForm", function (e) {
        e.preventDefault();
        
        let formData = new FormData(this);
        // If your form fields are named `name`, `description`, `parent_id`, and `type`,
        // FormData will automatically include them (assuming you have <select name="type" id="type">).
        
        $.ajax({
            type: "POST",
            url: "/storeGenre", // or your actual route
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.success) {
                    iziToast.show({
                        title: "Success",
                        message: "Genre Added Successfully",
                        color: "green",
                        position: "topRight",
                        timeout: 3000,
                    });

                    // Dynamically append the new genre to the parent select, if desired
                    let newOption = new Option(response.data.name, response.data.id);
                    $('#parent_id').append(newOption);

                    // Reload the DataTable to show the new genre
                    $("#genresTable").DataTable().ajax.reload();

                    // Close the modal
                    $("#genreModal").modal("hide");
                } else {
                    // Handle validation errors or server errors
                    // e.g., show error messages
                }
            },
            error: function (xhr) {
                console.log(xhr.responseText);
                // You can show an error toast here if needed
            }
        });
    });

    // 3) Edit Genre
    $("#genresTable").on("click", ".edit", function () {
        let id = $(this).data("id");

        $.get(`/genre/${id}/edit`, function (response) {
            if (response) {
                // Set the genre details in the modal fields
                $("#edit_name").val(response.genre.name);
                $("#edit_description").val(response.genre.description);

                // Populate the Parent Genre dropdown
                let parentSelect = $("#edit_parent_id");
                parentSelect.empty();
                parentSelect.append('<option value="">None</option>');

                response.parents.forEach(function(parent) {
                    let selected = (parent.id == response.genre.parent_id) ? 'selected' : '';
                    parentSelect.append(`<option value="${parent.id}" ${selected}>${parent.name}</option>`);
                });

                // Populate the Type dropdown (added code)
                $("#edit_type").val(response.genre.type);

                selectedGenreID = id;
                $("#editGenreModal").modal("show");
            }
        });
    });

    // 4) Update Genre
    $(document).on("submit", "#editGenreForm", function (e) {
        e.preventDefault();
        let formData = new FormData(this);
        formData.append("id", selectedGenreID);

        $.ajax({
            type: "POST",
            url: `/updateGenre`,
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.success) {
                    iziToast.show({
                        title: "Success",
                        message: "Genre Updated Successfully",
                        color: "green",
                        position: "topRight",
                        timeout: 3000,
                    });
                    $("#genresTable").DataTable().ajax.reload();
                    $("#editGenreModal").modal("hide");
                } else {
                    // Handle validation errors or server errors
                }
            },
            error: function (xhr) {
                console.log(xhr.responseText);
            }
        });
    });

    // 5) Delete Genre
    $("#genresTable").on("click", ".delete", function () {
        let id = $(this).data("id");

        swal({
            title: "Are you sure?",
            text: "You are about to delete this genre.",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((willDelete) => {
            if (willDelete) {
                $.ajax({
                    type: "POST",
                    url: "/destroyGenre",
                    data: { id: id, _token: $('meta[name="csrf-token"]').attr("content") },
                    success: function (response) {
                        if (response.success) {
                            iziToast.show({
                                title: "Deleted",
                                message: "Genre Deleted Successfully",
                                color: "green",
                                position: "topRight",
                                timeout: 3000,
                            });
                            $("#genresTable").DataTable().ajax.reload();
                        } else {
                            // Handle error (e.g. can't delete if has children, etc.)
                        }
                    },
                    error: function(xhr) {
                        console.log(xhr.responseText);
                    }
                });
            }
        });
    });
});
