$(document).ready(function () {
    $(".sideBarli").removeClass("activeLi");
    $(".PlaylistsMusicSideA").addClass("activeLi");
    var selectedPlaylistID = 0;

    $("#playlistsTable").dataTable({
        processing: true,
        serverSide: true,
        language: {
            paginate: {
                next: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="9 18 15 12 9 6"></polyline></svg>',
                previous: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="15 18 9 12 15 6"></polyline></svg>',
            },
        },
        ajax: {
            url: "/playlists_musicList",
            type: "POST",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
        },
        columns: [
            { data: "playlist_name", name: "playlist_id" },
            { data: "music", name: "music_id" },
            { data: "action", name: "action", orderable: false, searchable: false },
        ],
    });

    // Add Playlist Music
    $(document).on("submit", "#addPlaylistForm", function (e) {
        e.preventDefault();
        let formData = new FormData(this);

        $.ajax({
            type: "POST",
            url: "/storePlaylists_music",
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.success) {
                    iziToast.show({
                        title: "Success",
                        message: "Playlist Music Added Successfully",
                        color: "green",
                        position: "topRight",
                        timeout: 3000,
                    });
                    $("#playlistsTable").DataTable().ajax.reload();
                    $("#playlistModal").modal("hide");
                }
            },
        });
    });

    // Edit Playlist Music
    $("#playlistsTable").on("click", ".edit", function () {
        let id = $(this).data("id");

        $.get(`/playlists_music/${id}/edit`, function (response) {
            if (response.success) {
                // Populate the form fields
                $("#edit_playlist_id").val(response.playlist_id);
                $("#edit_music_id").val(response.music_id); // Populate music ID
                selectedPlaylistID = id;

                // Show the modal
                $("#editPlaylistModal").modal("show");
            }
        });
    });

    // Update Playlist Music
    $(document).on("submit", "#editPlaylistForm", function (e) {
        e.preventDefault();
        let formData = new FormData(this);
        formData.append("id", selectedPlaylistID);

        $.ajax({
            type: "POST",
            url: "/updatePlaylists_music",
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.success) {
                    iziToast.show({
                        title: "Success",
                        message: "Playlist Music Updated Successfully",
                        color: "green",
                        position: "topRight",
                        timeout: 3000,
                    });
                    $("#playlistsTable").DataTable().ajax.reload();
                    $("#editPlaylistModal").modal("hide");
                }
            },
        });
    });

    // Delete Playlist Music
    $("#playlistsTable").on("click", ".delete", function () {
        let id = $(this).data("id");

        swal({
            title: "Are you sure?",
            text: "You are about to delete this playlist music.",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((willDelete) => {
            if (willDelete) {
                $.ajax({
                    type: "POST",
                    url: "/destroyPlaylists_music",
                    data: { id: id, _token: $('meta[name="csrf-token"]').attr("content") },
                    success: function (response) {
                        if (response.success) {
                            iziToast.show({
                                title: "Deleted",
                                message: "Playlist Music Deleted Successfully",
                                color: "green",
                                position: "topRight",
                                timeout: 3000,
                            });
                            $("#playlistsTable").DataTable().ajax.reload();
                        }
                    },
                });
            }
        });
    });
});
