$.ajaxSetup({
    headers: {
        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
    }
});
$(document).ready(function () {
    const table = initDataTable();
    setupAddPodcastForm(table);
    setupEditPodcastForm(table);
    setupDeletePodcast(table);
    setupStatusToggle(table);
});


// ✅ Initialize DataTable
function initDataTable() {
    return $("#podcastTable").DataTable({
        processing: true,
        serverSide: true,
        serverMethod: "POST",
        aaSorting: [[0, "desc"]],
        ajax: {
            url: `${domainUrl}podcast/podcastList`,
            error: (error) => console.error("AJAX error:", error),
        },
        columns: [
            { data: "title" },
            { data: "description" },
            { data: "category" },
            {
                data: "episode",
                render: (data) => `<audio controls style="width: 100px;">
                    <source src="${data}" type="audio/mpeg"></audio>`,
            },
            { data: "episode_number" },
            { data: "duration" },
            { data: "start_date" },
            { data: "end_date" },
            { data: "likes" },
            { data: "plays" },
            {
                data: "active",
                render: (data, type, row) => `<input type="checkbox" class="active" rel="${row.id}" ${data ? "checked" : ""} />`,
            },
            {
                data: "id",
                render: (id) => `
                    <button class="btn btn-success btn-sm edit" data-id="${id}">Edit</button>
                    <button class="btn btn-danger btn-sm delete" data-id="${id}">Delete</button>
                `,
            },
        ],
    });
}

// ✅ Handle Add Podcast
function setupAddPodcastForm(table) {
    $("#addPodcastForm").submit(function (e) {
        e.preventDefault();
        let formData = new FormData(this);

        $.ajax({
            url: `${domainUrl}podcast`,
            method: "POST",
            data: formData,
            contentType: false,
            processData: false,
            success: () => {
                iziToast.success({ title: "Success", message: "Podcast added!", position: "topRight" });
                $("#podcastModal").modal("hide");
                table.ajax.reload(null, false);
            },
            error: (err) => console.error("Add error:", err),
        });
    });
}

// ✅ Handle Edit Podcast Load & Submit
function setupEditPodcastForm(table) {
    // Load data into modal
    $("#podcastTable").on("click", ".edit", function () {
        let id = $(this).data("id");

        $.get(`${domainUrl}podcast/${id}`, function (res) {
            if (res && res.data) {
                const data = res.data;
                $("#editPodcastID").val(data.id);
                $("#editTitle").val(data.title);
                $("#editDescription").val(data.description);
                $("#editCategory").val(data.podcast_category_id);
                $("#editStartDate").val(data.start_date);
                $("#editEndDate").val(data.end_date);
                $("#editLikes").val(data.likes);
                $("#editPlays").val(data.plays);
                $("#editEpisodeNumber").val(data.episode_number);

                $("#currentEpisode").html(data.episode ? `
                    <audio controls style="width: 100%;">
                        <source src="${data.episode}" type="audio/mpeg">
                    </audio>` : "No episode file");

                $("#editPodcastModal").modal("show");
            }
        }).fail((err) => console.error("Edit fetch error:", err));
    });

    // Submit updated data
    $("#editPodcastForm").submit(function (e) {
        e.preventDefault();
        let formData = new FormData(this);
        formData.append("_method", "POST");

        $.ajax({
            url: `${domainUrl}podcast/${formData.get("id")}`,
            method: "POST",
            data: formData,
            contentType: false,
            processData: false,
            success: () => {
                iziToast.success({ title: "Updated", message: "Podcast updated!", position: "topRight" });
                $("#editPodcastModal").modal("hide");
                table.ajax.reload(null, false);
            },
            error: (err) => console.error("Update error:", err),
        });
    });
}

// ✅ Handle Delete Podcast
function setupDeletePodcast(table) {
    $("#podcastTable").on("click", ".delete", function () {
        let id = $(this).data("id");

        if (confirm("Are you sure you want to delete this podcast?")) {
            $.ajax({
                url: `${domainUrl}podcast/${id}`,
                type: "POST",
                data: { _method: "DELETE" },
                success: () => {
                    iziToast.warning({ title: "Deleted", message: "Podcast deleted!", position: "topRight" });
                    table.ajax.reload(null, false);
                },
                error: (err) => console.error("Delete error:", err),
            });
        }
    });
}

// ✅ Toggle Active Status
function setupStatusToggle(table) {
    $(document).on("change", ".active", function () {
        const id = $(this).attr("rel");
        const value = $(this).prop("checked") ? 1 : 0;

        $.post(`${domainUrl}podcast/updateStatus`, { id, active: value }, function () {
            iziToast.show({
                title: "Success",
                message: value ? "Activated" : "Deactivated",
                color: "green",
                position: "topRight",
            });
            table.ajax.reload(null, false);
        }).fail((err) => console.error("Toggle error:", err));
    });
}
