$(document).ready(function () {
    // Set the active sidebar link
    $(".sideBarli").removeClass("activeLi");
    $(".PodcastCategoriesSideA").addClass("activeLi");

    let selectedPodcastCategoryID = 0;

    // Initialize DataTable for Podcast Categories
    $("#podcastCategoriesTable").dataTable({
        processing: true,
        serverSide: true,
        serverMethod: "post",
        aaSorting: [[0, "desc"]],
        language: {
            paginate: {
                next: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="9 18 15 12 9 6"></polyline></svg>',
                previous: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="15 18 9 12 15 6"></polyline></svg>',
            },
        },
        columnDefs: [
            {
                targets: [0, 1],
                orderable: false,
            },
        ],
        ajax: {
            url: `${domainUrl}podcastCategoryList`, // API endpoint for fetching categories
            error: function (error) {
                console.error("Error fetching podcast categories:", error);
            },
        },
    });

    // Add Podcast Category
    $(document).on("submit", "#addPodcastCategoryForm", function (e) {
        e.preventDefault();
        const formData = new FormData(this);

        $.ajax({
            type: "POST",
            url: `${domainUrl}addPodcastCategory`, // API endpoint for adding a category
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.status) {
                    iziToast.show({
                        title: "Success",
                        message: "Podcast Category Added Successfully",
                        color: "green",
                        position: toastPosition,
                        timeout: 3000,
                        iconUrl: `${domainUrl}asset/img/check-circle.svg`,
                    });
                    $("#podcastCategoriesTable").DataTable().ajax.reload(null, false);
                    $("#podcastCategoryModal").modal("hide");
                } else {
                    iziToast.show({
                        title: "Error",
                        message: response.message || "Failed to add Podcast Category",
                        color: "red",
                        position: toastPosition,
                        timeout: 3000,
                        iconUrl: `${domainUrl}asset/img/x.svg`,
                    });
                }
            },
            error: function (xhr, status, error) {
                console.error("Error adding podcast category:", error);
            },
        });
    });

    // Edit Podcast Category
    $("#podcastCategoriesTable").on("click", ".edit", function (e) {
        e.preventDefault();

        selectedPodcastCategoryID = $(this).attr("rel");
        const categoryName = $(this).data("category_name");
        const description = $(this).data("description");
        const artistID = $(this).data("artist_id");
        const tags = $(this).data("tags");
        const imageUrl = $(this).data("image");

        $("#editName").val(categoryName);
        $("#editDescription").val(description);
        $("#editArtist").val(artistID);
        $("#editTags").val(tags);

        if (imageUrl) {
            $("#editImage").siblings(".preview").remove();
            $("#editImage").after(
                `<img src="${imageUrl}" class="preview" style="max-height: 100px; margin-top: 10px;">`
            );
        }

        $("#editPodcastCategoryModal").modal("show");
    });

    // Update Podcast Category
    $(document).on("submit", "#editPodcastCategoryForm", function (e) {
        e.preventDefault();
        const formData = new FormData(this);
        formData.append("id", selectedPodcastCategoryID);

        $.ajax({
            type: "POST",
            url: `${domainUrl}updatePodcastCategory`, // API endpoint for updating a category
            data: formData,
            contentType: false,
            processData: false,
            success: function (response) {
                if (response.status) {
                    iziToast.show({
                        title: "Success",
                        message: "Podcast Category Updated Successfully",
                        color: "green",
                        position: toastPosition,
                        timeout: 3000,
                        iconUrl: `${domainUrl}asset/img/check-circle.svg`,
                    });
                    $("#podcastCategoriesTable").DataTable().ajax.reload(null, false);
                    $("#editPodcastCategoryModal").modal("hide");
                } else {
                    iziToast.show({
                        title: "Error",
                        message: response.message || "Failed to update Podcast Category",
                        color: "red",
                        position: toastPosition,
                        timeout: 3000,
                        iconUrl: `${domainUrl}asset/img/x.svg`,
                    });
                }
            },
            error: function (xhr, status, error) {
                console.error("Error updating podcast category:", error);
            },
        });
    });

    // Delete Podcast Category
    $("#podcastCategoriesTable").on("click", ".delete", function (e) {
        e.preventDefault();
        const id = $(this).attr("rel");

        swal({
            title: "Are you sure?",
            icon: "warning",
            buttons: true,
            dangerMode: true,
        }).then((confirmDelete) => {
            if (confirmDelete) {
                $.ajax({
                    type: "POST",
                    url: `${domainUrl}deletePodcastCategory`, // API endpoint for deleting a category
                    data: { id: id },
                    success: function (response) {
                        if (response.status) {
                            iziToast.show({
                                title: "Success",
                                message: "Podcast Category Deleted Successfully",
                                color: "green",
                                position: toastPosition,
                                timeout: 3000,
                                iconUrl: `${domainUrl}asset/img/check-circle.svg`,
                            });
                            $("#podcastCategoriesTable").DataTable().ajax.reload(null, false);
                        } else {
                            iziToast.show({
                                title: "Error",
                                message: response.message || "Failed to delete Podcast Category",
                                color: "red",
                                position: toastPosition,
                                timeout: 3000,
                                iconUrl: `${domainUrl}asset/img/x.svg`,
                            });
                        }
                    },
                    error: function (xhr, status, error) {
                        console.error("Error deleting podcast category:", error);
                    },
                });
            }
        });
    });
});
