@extends('include.app')

@section('header')
    <script src="{{ asset('asset/script/artists.js') }}"></script>
@endsection

@section('content')
<section class="section">
    <div class="card">
        <div class="card-header">
            <div class="page-title w-100">
                <div class="d-flex align-items-center justify-content-between">
                    <h4 class="mb-0 fw-semibold text-capitalize">{{ __('Artists') }}</h4>
                    <button type="button" class="btn theme-bg theme-btn text-white text-capitalize" data-bs-toggle="modal"
                        data-bs-target="#artistModal" id="addArtist">
                        {{ __('Add Artist') }}
                    </button>
                </div>
            </div>
        </div>
        <div class="card-body">
            <table class="table table-striped w-100" id="artistsTable">
                <thead>
                    <tr>
                        <th>{{ __('Name') }}</th>
                        <th>{{ __('Image') }}</th> <!-- Image column moved after Name -->
                        <th>{{ __('Description') }}</th>
                        <th>{{ __('Background Info') }}</th>
                        <th>{{ __('Personality Traits') }}</th>
                        <th>{{ __('Appearance Details') }}</th>
                        <th>{{ __('Action') }}</th>
                    </tr>
                </thead>
            </table>
        </div>
    </div>
</section>

<!-- Add Artist Modal -->
<div class="modal fade" id="artistModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">{{ __('Add Artist') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="addArtistForm" method="post" enctype="multipart/form-data"> <!-- Added enctype for file upload -->
                <div class="modal-body">
                    <div class="form-group">
                        <label for="name" class="form-label">{{ __('Name') }}</label>
                        <input type="text" class="form-control" name="name" id="name" required>
                    </div>
                    <div class="form-group"> <!-- New field for image -->
                        <label for="image" class="form-label">{{ __('Image') }}</label>
                        <input type="file" class="form-control" name="image" id="image" accept="image/*">
                    </div>
                    <div class="form-group">
                        <label for="description" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="description" required></textarea>
                    </div>
                    <div class="form-group">
                        <label for="background_info" class="form-label">{{ __('Background Info') }}</label>
                        <textarea class="form-control" name="background_info" id="background_info"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="personality_traits" class="form-label">{{ __('Personality Traits') }}</label>
                        <textarea class="form-control" name="personality_traits" id="personality_traits"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="appearance_details" class="form-label">{{ __('Appearance Details') }}</label>
                        <textarea class="form-control" name="appearance_details" id="appearance_details"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn"
                        data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Edit Artist Modal -->
<div class="modal fade" id="editArtistModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">{{ __('Edit Artist') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="editArtistForm" method="post" enctype="multipart/form-data"> <!-- Added enctype for file upload -->
                <input type="hidden" id="artistID">
                <div class="modal-body">
                    <div class="form-group">
                        <label for="edit_name" class="form-label">{{ __('Name') }}</label>
                        <input type="text" class="form-control" name="name" id="edit_name" required>
                    </div>
                    <div class="form-group"> <!-- New field for image -->
                        <label for="edit_image" class="form-label">{{ __('Image') }}</label>
                        <input type="file" class="form-control" name="image" id="edit_image" accept="image/*">
                        <img id="currentImage" src="" alt="{{ __('Current Image') }}" class="img-thumbnail mt-2" style="max-width: 150px;"> <!-- For showing current image -->
                    </div>
                    <div class="form-group">
                        <label for="edit_description" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="edit_description" required></textarea>
                    </div>
                    <div class="form-group">
                        <label for="edit_background_info" class="form-label">{{ __('Background Info') }}</label>
                        <textarea class="form-control" name="background_info" id="edit_background_info"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="edit_personality_traits" class="form-label">{{ __('Personality Traits') }}</label>
                        <textarea class="form-control" name="personality_traits" id="edit_personality_traits"></textarea>
                    </div>
                    <div class="form-group">
                        <label for="edit_appearance_details" class="form-label">{{ __('Appearance Details') }}</label>
                        <textarea class="form-control" name="appearance_details" id="edit_appearance_details"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn"
                        data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton1">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>
@endsection
