@extends('include.app')

@section('header')
    <script src="{{ asset('asset/script/genres.js') }}"></script>
@endsection

@section('content')
<section class="section">
    <div class="card">
        <div class="card-header">
            <div class="page-title w-100">
                <div class="d-flex align-items-center justify-content-between">
                    <h4 class="mb-0 fw-semibold text-capitalize">{{ __('Genres') }}</h4>
                    <button type="button" class="btn theme-bg theme-btn text-white text-capitalize" 
                            data-bs-toggle="modal" data-bs-target="#genreModal" id="addGenre">
                        {{ __('Add Genre') }}
                    </button>
                </div>
            </div>
        </div>
        <div class="card-body">
            <table class="table table-striped w-100" id="genresTable">
                <thead>
                    <tr>
                        <th>{{ __('Name') }}</th>
                        <th>{{ __('Description') }}</th>
                        <th>{{ __('Parent Genre') }}</th>
                        <!-- Optionally, add a column for 'Type' if you want to display it in the table -->
                        <th>{{ __('Type') }}</th>
                        <th style="text-align: right">{{ __('Action') }}</th>
                    </tr>
                </thead>
            </table>
        </div>
    </div>
</section>

<!-- Add Genre Modal -->
<div class="modal fade" id="genreModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">{{ __('Add Genre') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="addGenreForm" method="post">
                <div class="modal-body">
                    <div class="form-group mb-3">
                        <label for="name" class="form-label">{{ __('Name') }}</label>
                        <input type="text" class="form-control" name="name" id="name" required>
                    </div>
                    <div class="form-group mb-3">
                        <label for="description" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="description"></textarea>
                    </div>
                    <div class="form-group mb-3">
                        <label for="parent_id" class="form-label">{{ __('Parent Genre') }}</label>
                        <select class="form-control" name="parent_id" id="parent_id">
                            <option value="">{{ __('None') }}</option>
                            @foreach($parents as $parent)
                                <option value="{{ $parent->id }}">{{ $parent->name }}</option>
                            @endforeach
                        </select>
                    </div>
                    <!-- NEW: Type field -->
                    <div class="form-group mb-3">
                        <label for="type" class="form-label">{{ __('Type') }}</label>
                        <select class="form-control" name="type" id="type" required>
                            <option value="">-- Select Type --</option>
                            <option value="indica">Indica</option>
                            <option value="sativa">Sativa</option>
                            <option value="hybrid">Hybrid</option>
                            <option value="meditation">Meditation</option>
                        </select>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">
                        {{ __('Cancel') }}
                    </button>
                    <button type="submit" class="btn theme-btn text-white saveButton">
                        {{ __('Save') }}
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Edit Genre Modal -->
<div class="modal fade" id="editGenreModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">
                    {{ __('Edit Genre') }}
                </h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="editGenreForm" method="post">
                <input type="hidden" id="genreID"> <!-- For storing the ID of the genre being edited -->
                <div class="modal-body">
                    <div class="form-group mb-3">
                        <label for="edit_name" class="form-label">{{ __('Name') }}</label>
                        <input type="text" class="form-control" name="name" id="edit_name" required>
                    </div>
                    <div class="form-group mb-3">
                        <label for="edit_description" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="edit_description"></textarea>
                    </div>
                    <div class="form-group mb-3">
                        <label for="edit_parent_id" class="form-label">{{ __('Parent Genre') }}</label>
                        <select class="form-control" name="parent_id" id="edit_parent_id">
                            <option value="">{{ __('None') }}</option>
                            <!-- Parent genres are dynamically added via JS -->
                        </select>
                    </div>
                    <!-- NEW: Type field for Edit -->
                    <div class="form-group mb-3">
                        <label for="edit_type" class="form-label">{{ __('Type') }}</label>
                        <select class="form-control" name="type" id="edit_type" required>
                            <option value="">-- Select Type --</option>
                            <option value="indica">Indica</option>
                            <option value="sativa">Sativa</option>
                            <option value="hybrid">Hybrid</option>
                            <option value="meditation">Meditation</option>
                        </select>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">
                        {{ __('Cancel') }}
                    </button>
                    <button type="submit" class="btn theme-btn text-white saveButton1">
                        {{ __('Save') }}
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>
@endsection
