@extends('include.app')

@section('header')
    <script src="{{ asset('asset/script/music.js') }}"></script>
@endsection

@section('content')

<!-- CSS -->
<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/@yaireo/tagify/dist/tagify.css">
<!-- JS -->
<script src="https://cdn.jsdelivr.net/npm/@yaireo/tagify"></script>

<section class="section">
    <div class="card">
        <div class="card-header">
            <div class="page-title w-100">
                <div class="d-flex align-items-center justify-content-between">
                    <h4 class="mb-0 fw-semibold text-capitalize">{{ __('Musics') }}</h4>
                    <button type="button" class="btn theme-bg theme-btn text-white text-capitalize"
                            data-bs-toggle="modal" data-bs-target="#musicModal">
                        {{ __('Add Music') }}
                    </button>
                </div>
            </div>
        </div>
        <div class="card-body">
            
            <!-- FILTERS ROW: Album, Type, Tag, Artist -->
            <div class="row mb-3">
                <!-- Filter by Album -->
                <div class="col-md-3">
                    <select id="filterAlbum" class="form-control form-control-sm">
                        <option value="">All Albums</option>
                        @foreach($categories as $cat)
                            <option value="{{ $cat->id }}">{{ $cat->title }}</option>
                        @endforeach
                    </select>
                </div>

                <!-- Filter by Type (Free or Premium) -->
                <div class="col-md-3">
                
                    <select id="filterType" class="form-control form-control-sm">
                        <option value="">All Types</option>
                        <option value="0">Free</option>
                        <option value="1">Premium</option>
                    </select>
                </div>

                <!-- Filter by Tag -->
               <!-- Replace Filter by Tag dropdown with a text input -->
    <div class="col-md-3">
       
        <input type="text" id="filterTag" class="form-control form-control-sm" placeholder="Type a tag..."/>
    </div>


                <!-- Filter by Artist -->
                <div class="col-md-3">
                   
                    <select id="filterArtist" class="form-control form-control-sm">
                        <option value="">All Artists</option>
                        @foreach($artists as $artistId => $artistName)
                            <option value="{{ $artistName }}">{{ $artistName }}</option>
                        @endforeach
                    </select>
                </div>
            </div>

            <!-- DataTable -->
            <table class="table table-striped w-100" id="musicTable">
                <thead>
                    <tr>
                        <th width="100px">{{ __('Image') }}</th>
                        <th width="25%" class="music_td">{{ __('Music') }}</th>
                        <th>{{ __('Title') }}</th>
                        <th>{{ __('Tag') }}</th>
                        <th>{{ __('Plays') }}</th>
                        <th>{{ __('Album') }}</th>
                        <th>{{ __('Type') }}</th>
                        <th>{{ __('Featured') }}</th>
                        <th>{{ __('Active') }}</th>
                        <th>{{ __('Artist') }}</th>
                        <th width="200px" style="text-align: right">{{ __('Action') }}</th>
                    </tr>
                </thead>
            </table>
        </div>
    </div>
</section>

<!-- Music Modal -->
<div class="modal fade" id="musicModal" tabindex="-1" aria-labelledby="exampleModalLabel">
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">{{ __('Add Music') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <!-- Make sure to include @csrf and enctype for file uploads if not using purely AJAX -->
            <form id="addMusicForm" method="post" enctype="multipart/form-data">
                @csrf
                <div class="modal-body">
                    <div class="form-group mb-3">
                        <label for="title" class="form-label">{{ __('Title') }}</label>
                        <input type="text" class="form-control" name="title" id="title" required="">
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label class="form-label">{{ __('Album') }}</label>
                                <select name="category_id" id="category" class="form-control" required>
                                    <option value="" disabled selected>{{ __('Select Option') }}</option>
                                    @foreach ($categories as $category)
                                        <option value="{{ $category->id }}">{{ $category->title }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label class="form-label">{{ __('Select Type') }} </label>
                                <select name="type" id="type" class="form-control" required>
                                    <option value="" disabled selected>{{ __('Select Type') }}</option>
                                    <option value="0">{{ __('Free') }}</option>
                                    <option value="1">{{ __('Premium') }}</option>
                                </select>
                            </div>
                        </div>
                    </div>
                    <!-- Lyrics -->
                    <div class="form-group mb-3">
                        <label class="form-label">{{ __('Lyrics') }}</label>
                        <div id="lyricsContent" class="quillEditorLyrics"></div>
                    </div>
                    <!-- Hidden input for lyrics if needed -->
                    <input type="hidden" name="lyrics" />

                    <!-- Tags -->
                    <div class="form-group mb-3">
                        <label class="form-label">{{ __('Tags') }}</label>
                        <input type="text" class="form-control" name="tags" id="tags" placeholder="Add tags" required>
                    </div>

                    <div class="row">
                        <div class="col-md-8">
                            <div class="form-group mb-3">
                                <label for="uploadMusic" class="form-label">{{ __('Music') }}</label>
                                <label for="uploadMusic" class="iconformusic">
                                    {{ __('Select music') }}
                                </label>
                                <input type="file" class="form-control" id="uploadMusic" name="audio"
                                       style="display: none;" accept="audio/mp3,audio/*;capture=microphone">
                                <audio id="audio" src="" controls></audio>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group float-end mb-3">
                                <label for="image" class="form-label">{{ __('Image') }}</label>
                                <div class="posterImg">
                                    <div class="upload-options">
                                        <label for="poster">
                                            <input type="file" accept=".png, .jpg, .jpeg, .webp"
                                                   onchange="loadFile(event)" name="image" id="poster" required>
                                        </label>
                                    </div>
                                    <img id="posterImg" class="custom_img img-fluid"
                                         src="{{ asset('asset/img/placeholder-image.png') }}">
                                </div>
                            </div>
                        </div>
                    </div>
                </div> <!-- modal-body -->
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Edit music Modal -->
<div class="modal fade" id="editMusicModal" tabindex="-1" aria-labelledby="exampleModalLabel" >
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">
                    {{ __('Edit Music') }}
                </h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="editMusicForm" method="post" enctype="multipart/form-data">
                @csrf
                <div class="modal-body">
                    <div class="form-group mb-3">
                        <label for="edit_title" class="form-label">{{ __('Title') }}</label>
                        <input type="text" class="form-control" name="title" id="edit_title" required="">
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label class="form-label">{{ __('Category') }}</label>
                                <select name="category_id" id="edit_category" class="form-control" required>
                                    <option value="" disabled selected>{{ __('Select Option') }}</option>
                                    @foreach ($categories as $category)
                                        <option value="{{ $category->id }}">{{ $category->title }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label class="form-label">{{ __('Select Type') }}</label>
                                <select name="type" id="edit_type" class="form-control" required>
                                    <option value="" disabled selected>{{ __('Select Type') }}</option>
                                    <option value="0">{{ __('Free') }}</option>
                                    <option value="1">{{ __('Premium') }}</option>
                                </select>
                            </div>
                        </div>
                    </div>

                    <!-- Lyrics -->
                    <div class="form-group mb-3">
                        <label class="form-label">{{ __('Lyrics') }}</label>
                        <div id="lyricsContentEdit" class="quillEditorLyricsEdit"></div>
                    </div>
                    <!-- Hidden input for lyrics -->
                    <input type="hidden" name="lyrics" />

                    <!-- Tags -->
                    <div class="form-group mb-3">
                        <label class="form-label">{{ __('Tags') }}</label>
                        <input type="text" class="form-control" name="tag" id="tagEdit" required="">
                    </div>

                    <div class="row">
                        <div class="col-md-8">
                            <div class="form-group mb-3">
                                <label for="editUploadMusic" class="form-label">{{ __('Music') }}</label>
                                <label for="editUploadMusic" class="iconformusic">
                                    {{ __('Select music') }}
                                    <input type="file" class="form-control" id="editUploadMusic" name="audio"
                                           style="display: none;" accept="audio/mp3,audio/*;capture=microphone">
                                </label>
                                <audio id="edit_audio" src="" controls></audio>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group mb-3">
                                <label for="image" class="form-label">{{ __('Image') }}</label>
                                <div class="posterImg">
                                    <div class="upload-options">
                                        <label for="edit_poster">
                                            <input type="file" accept=".png, .jpg, .jpeg, .webp"
                                                   onchange="loadFileEdit(event)" name="image" id="edit_poster">
                                        </label>
                                    </div>
                                    <img id="edit_musicImg" class="custom_img img-fluid"
                                         src="{{ asset('asset/img/placeholder-image.png') }}">
                                </div>
                            </div>
                        </div>
                    </div>
                </div> <!-- modal-body -->
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    function handleFiles1(event) {
        var files1 = event.target.files;
        $("#audio").attr("src", URL.createObjectURL(files1[0]));
        document.getElementById("audio").load();
    }
    document.getElementById("uploadMusic").addEventListener("change", handleFiles1, false);

    function handleFiles(event) {
        var files = event.target.files;
        $("#edit_audio").attr("src", URL.createObjectURL(files[0]));
        document.getElementById("edit_audio").load();
    }
    document.getElementById("editUploadMusic").addEventListener("change", handleFiles, false);

    var loadFile = function(event) {
        var output = document.getElementById('posterImg');
        output.src = URL.createObjectURL(event.target.files[0]);
        output.onload = function() {
            URL.revokeObjectURL(output.src)
        }
    };
    var loadFileEdit = function(event) {
        var output1 = document.getElementById('edit_musicImg');
        output1.src = URL.createObjectURL(event.target.files[0]);
        output1.onload = function() {
            URL.revokeObjectURL(output1.src)
        }
    };
</script>
@endsection
