@extends('include.app')

@section('header')
    <script src="{{ asset('asset/script/podcast.js') }}"></script>
@endsection

@section('content')

    <section class="section">
        <div class="card">
            <div class="card-header">
                <div class="page-title w-100">
                    <div class="d-flex align-items-center justify-content-between">
                        <h4 class="mb-0 fw-semibold text-capitalize">{{ __('Podcasts') }}</h4>
                        <button type="button" class="btn theme-bg theme-btn text-white text-capitalize" data-bs-toggle="modal"
                            data-bs-target="#podcastModal" id="addPodcast">
                            {{ __('Add Episodes') }}
                        </button>
                    </div>
                </div>
            </div>
            <div class="card-body">
                <table class="table table-striped w-100" id="podcastTable">
                   <thead>
    <tr>
        <th width="100px">{{ __('Title') }}</th>
        <th width="200px">{{ __('Description') }}</th>
        <th width="100px">{{ __('Category') }}</th>
        <th width="100px">{{ __('Episode') }}</th>
        <th width="100px">{{ __('Episode Number') }}</th> <!-- ✅ Add Episode Number -->
        <th width="100px">{{ __('Duration') }}</th> <!-- ✅ Add Duration -->
        <th width="100px">{{ __('Start Date') }}</th>
        <th width="100px">{{ __('End Date') }}</th>
        <th width="50px">{{ __('Likes') }}</th>
        <th width="50px">{{ __('Plays') }}</th>
        <th width="100px">{{ __('Active') }}</th>
        <th width="200px" style="text-align: right">{{ __('Action') }}</th>
    </tr>
</thead>

                </table>
            </div>
        </div>
    </section>

<!-- Add Podcast Modal -->
<div class="modal fade" id="podcastModal" tabindex="-1" aria-labelledby="addPodcastLabel" aria-hidden="true">
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="addPodcastLabel">{{ __('Add Episode') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="addPodcastForm" method="post" enctype="multipart/form-data">
                @csrf
                <div class="modal-body">
                    <div class="form-group">
                        <label for="title" class="form-label">{{ __('Title') }}</label>
                        <input type="text" class="form-control" name="title" id="title" required>
                    </div>

                    <div class="form-group">
                        <label for="description" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="description" rows="3" required></textarea>
                    </div>

                    <div class="form-group">
                        <label for="podcast_category_id" class="form-label">{{ __('Category') }}</label>
                        <select name="podcast_category_id" id="podcast_category_id" required class="form-control">
                            @foreach ($podcast_categories as $podcast_category)
                                <option value="{{ $podcast_category->id }}">{{ $podcast_category->name }}</option>
                            @endforeach
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="episode" class="form-label">{{ __('Episode') }}</label>
                        <input type="file" name="episode" id="episode" class="form-control" required>
                    </div>
<!-- Episode Number -->
<div class="form-group">
    <label for="episode_number" class="form-label">{{ __('Episode Number') }}</label>
    <input type="number" name="episode_number" id="episode_number" class="form-control" min="1" required>
</div>

                    <div class="form-group">
                        <label for="start_date" class="form-label">{{ __('Start Date') }}</label>
                        <input type="date" name="start_date" id="start_date" class="form-control" required>
                    </div>

                    <div class="form-group">
                        <label for="end_date" class="form-label">{{ __('End Date') }}</label>
                        <input type="date" name="end_date" id="end_date" class="form-control" required>
                    </div>

                    <div class="form-group">
                        <label for="likes" class="form-label">{{ __('Likes') }}</label>
                        <input type="number" name="likes" id="likes" class="form-control" value="0" min="0" required>
                    </div>

                    <div class="form-group">
                        <label for="plays" class="form-label">{{ __('Plays') }}</label>
                        <input type="number" name="plays" id="plays" class="form-control" value="0" min="0" required>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>

    <!-- Edit Podcast Modal -->
    <div class="modal fade" id="editPodcastModal" tabindex="-1" aria-labelledby="editPodcastLabel" aria-hidden="true">
        <div class="modal-dialog modal-sm-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="editPodcastLabel">{{ __('Edit Episode') }}
                    </h1>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form id="editPodcastForm" method="post">
                    <input type="hidden" name="id" id="editPodcastID"> <!-- Hidden field for podcast ID -->
                    <div class="modal-body">
                        <!-- Title -->
                        <div class="form-group">
                            <label for="editTitle" class="form-label">{{ __('Title') }}</label>
                            <input type="text" class="form-control" name="title" id="editTitle" required>
                        </div>

                        <!-- Description -->
                        <div class="form-group">
                            <label for="editDescription" class="form-label">{{ __('Description') }}</label>
                            <textarea class="form-control" name="description" id="editDescription" rows="3" required></textarea>
                        </div>

                        <!-- Category -->
                        <div class="form-group">
                            <label for="editCategory" class="form-label">{{ __('Category') }}</label>
                            <select name="podcast_category_id" id="editCategory" required class="form-control">
                                @if (isset($podcast_categories) && count($podcast_categories) > 0)
                                    @foreach ($podcast_categories as $podcast_category)
                                        <option value="{{ $podcast_category->id }}">{{ $podcast_category->name }}</option>
                                    @endforeach
                                @else
                                    <option value="No Category found" disabled>No Category Found</option>
                                @endif
                            </select>
                        </div>
<!-- ✅ Add this inside the modal -->
<div class="form-group">
    <label class="form-label">{{ __('Current Episode') }}</label>
    <div id="currentEpisode"></div> <!-- ✅ Placeholder for the existing episode -->
</div>

<!-- ✅ Allow users to upload a new episode -->
<div class="form-group">
    <label for="editEpisode" class="form-label">{{ __('Upload New Episode') }}</label>
    <input type="file" name="episode" id="editEpisode" class="form-control">
</div>

                        <!-- Start Date -->
                        <div class="form-group">
                            <label for="editStartDate" class="form-label">{{ __('Start Date') }}</label>
                            <input type="date" name="start_date" id="editStartDate" class="form-control" required>
                        </div>

                        <!-- End Date -->
                        <div class="form-group">
                            <label for="editEndDate" class="form-label">{{ __('End Date') }}</label>
                            <input type="date" name="end_date" id="editEndDate" class="form-control" required>
                        </div>
<!-- Episode Number -->
<div class="form-group">
    <label for="editEpisodeNumber" class="form-label">{{ __('Episode Number') }}</label>
    <input type="number" name="episode_number" id="editEpisodeNumber" class="form-control" min="1" required>
</div>

                        <!-- Likes -->
                        <div class="form-group">
                            <label for="editLikes" class="form-label">{{ __('Likes') }}</label>
                            <input type="number" name="likes" id="editLikes" class="form-control" min="0" required>
                        </div>

                        <!-- Plays -->
                        <div class="form-group">
                            <label for="editPlays" class="form-label">{{ __('Plays') }}</label>
                            <input type="number" name="plays" id="editPlays" class="form-control" min="0" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn modal-cancel-btn"
                            data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                        <button type="submit" class="btn theme-btn text-white saveButton1">{{ __('Save') }}</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

@endsection

