@extends('include.app')

@section('header')
    <script src="{{ asset('asset/script/podcast_categories.js') }}"></script>
@endsection

@section('content')

<section class="section">
    <div class="card">
        <div class="card-header">
            <div class="page-title w-100">
                <div class="d-flex align-items-center justify-content-between">
                    <h4 class="mb-0 fw-semibold text-capitalize">{{ __('Podcasts ') }}</h4>
                    <button type="button" class="btn theme-bg theme-btn text-white text-capitalize" data-bs-toggle="modal"
                        data-bs-target="#podcastCategoryModal" id="addPodcastCategory">
                        {{ __('Add Podcast') }}
                    </button>
                </div>
            </div>
        </div>
        <div class="card-body">
            <table class="table table-striped w-100" id="podcastCategoriesTable">
                <thead>
                    <tr>
                        <th>{{ __('Title') }}</th>
                        <th>{{ __('Description') }}</th>
                        <th>{{ __('Artist') }}</th>
                        <th>{{ __('Tags') }}</th>
                        <th>{{ __('Image') }}</th>
                        <th style="text-align: right">{{ __('Action') }}</th>
                    </tr>
                </thead>
            </table>
        </div>
    </div>
</section>

<!-- Add Podcast Category Modal -->
<div class="modal fade" id="podcastCategoryModal" tabindex="-1" aria-labelledby="addPodcastCategoryLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="addPodcastCategoryLabel">{{ __('Add Podcast') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="addPodcastCategoryForm" method="post" enctype="multipart/form-data">
                <div class="modal-body">
                    <!-- Category Name -->
                    <div class="form-group">
                        <label for="name" class="form-label">{{ __('Podcast Title') }}</label>
                        <input type="text" class="form-control" name="name" id="name" required>
                    </div>

                    <!-- Description -->
                    <div class="form-group">
                        <label for="description" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="description" rows="3"></textarea>
                    </div>

                    <!-- Artist -->
                    <div class="form-group">
                        <label for="artist" class="form-label">{{ __('Artist') }}</label>
                        <select name="artist_id" id="artist" class="form-control" required>
                            @foreach ($artists as $artist)
                                <option value="{{ $artist->id }}">{{ $artist->name }}</option>
                            @endforeach
                        </select>
                    </div>

                    <!-- Tags -->
                    <div class="form-group">
                        <label for="tags" class="form-label">{{ __('Tags') }}</label>
                        <input type="text" class="form-control" name="tags" id="tags" placeholder="e.g., tag1, tag2">
                    </div>

                    <!-- Image -->
                    <div class="form-group">
                        <label for="image" class="form-label">{{ __('Image') }}</label>
                        <input type="file" class="form-control" name="image" id="image">
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Edit Podcast Category Modal -->
<div class="modal fade" id="editPodcastCategoryModal" tabindex="-1" aria-labelledby="editPodcastCategoryLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="editPodcastCategoryLabel">{{ __('Edit Podcast') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="editPodcastCategoryForm" method="post" enctype="multipart/form-data">
                <input type="hidden" id="podcastCategoryID">
                <div class="modal-body">
                    <!-- Category Name -->
                    <div class="form-group">
                        <label for="editName" class="form-label">{{ __('Podcast Title') }}</label>
                        <input type="text" class="form-control" name="name" id="editName" required>
                    </div>

                    <!-- Description -->
                    <div class="form-group">
                        <label for="editDescription" class="form-label">{{ __('Description') }}</label>
                        <textarea class="form-control" name="description" id="editDescription" rows="3"></textarea>
                    </div>

                    <!-- Artist -->
                    <div class="form-group">
                        <label for="editArtist" class="form-label">{{ __('Artist') }}</label>
                        <select name="artist_id" id="editArtist" class="form-control" required>
                            @foreach ($artists as $artist)
                                <option value="{{ $artist->id }}">{{ $artist->name }}</option>
                            @endforeach
                        </select>
                    </div>

                    <!-- Tags -->
                    <div class="form-group">
                        <label for="editTags" class="form-label">{{ __('Tags') }}</label>
                        <input type="text" class="form-control" name="tags" id="editTags" placeholder="e.g., tag1, tag2">
                    </div>

                    <!-- Image -->
                    <div class="form-group">
                        <label for="editImage" class="form-label">{{ __('Image') }}</label>
                        <input type="file" class="form-control" name="image" id="editImage">
                        <small class="form-text text-muted">{{ __('Leave empty to retain the existing image') }}</small>
                        <div id="imagePreview" class="mt-2">
                            <!-- Preview for the existing image -->
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>

@endsection
