<?php

namespace App\Http\Controllers;

use App\Models\VibeOption;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class AdminVibeOptionController extends Controller
{
    public function index()
    {
        $vibes = VibeOption::all();
        return view('admin.vibes.index', compact('vibes'));
    }

    public function create()
    {
        return view('admin.vibes.create');
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'key' => 'required|unique:vibe_options,key',
            'emoji' => 'required',
            'label' => 'required',
            'message' => 'required',
            'eq_strategy' => 'nullable|string',
            'home_focus' => 'nullable|string',
            'active' => 'boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        VibeOption::create($request->all());

        return redirect()->route('admin.vibes.index')->with('success', 'Vibe option created.');
    }

    public function edit($id)
    {
        $vibe = VibeOption::findOrFail($id);
        return view('admin.vibes.edit', compact('vibe'));
    }

    public function update(Request $request, $id)
    {
        $vibe = VibeOption::findOrFail($id);

        $validator = Validator::make($request->all(), [
            'emoji' => 'required',
            'label' => 'required',
            'message' => 'required',
            'eq_strategy' => 'nullable|string',
            'home_focus' => 'nullable|string',
            'active' => 'boolean',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $vibe->update($request->all());

        return redirect()->route('admin.vibes.index')->with('success', 'Vibe updated successfully.');
    }

    public function destroy($id)
    {
        VibeOption::destroy($id);
        return redirect()->route('admin.vibes.index')->with('success', 'Vibe deleted.');
    }
}
