<?php
namespace App\Http\Controllers;

use App\Models\Article;
use App\Models\Album;
use App\Models\Artist;
use App\Models\Genre;
use App\Models\GlobalFunction;
use App\Models\Music;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    public function categories()
    {
        $genres = Genre::all();
        $artists = Artist::all();
        return view('categories', compact("genres", "artists"));
    }
    
    public function categoryList(Request $request)
    {
        $totalData = Album::count();
        $rows = Album::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'image',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = Album::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = Album::Where('title', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = Album::Where('title', 'LIKE', "%{$search}%")->count();
        }
        $data = [];
        foreach ($result as $item) {
            
            $item->load("genre");
            $item->load("artist");

            $imageUrl = GlobalFunction::createMediaUrl($item->image);

            if ($item->image != null) {
                $image = "<img src=". $imageUrl ." class='tbl_img'>";
            } else {
                $image = "<img src='./asset/img/placeholder-image.png' class='tbl_img'>";
            }
            if ($item->image == null) {
                $imageUrl = "null";
            }

            $edit = '<a href="#" data-genre="'.$item->genre_id.'" data-artist="'.$item->artist_id.'" data-title="'.$item->title.'" data-image="'.$imageUrl.'"  rel='.$item->id.' class="btn edit btn-success me-3">' . __('Edit') . '</a>'; 
            $delete = '<a href="#" class="btn delete btn-danger" rel=' . $item->id . '>' . __('Delete') . '</a>';
            $action = '<span class="float-end">'. $edit . $delete .' </span>' ;

            $data[] = [   
                $image,           
                $item->title,
                $item->artist ? $item->artist->name : 'No Artist',
                $item->genre ? $item->genre->name : 'No Genre',
                $action
            ];
        }
        $json_data = [
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($totalData),
            'recordsFiltered' => $totalFiltered,
            'data' => $data,
        ];
        echo json_encode($json_data);
        exit();
    }

    public function addCategory(Request $request)
    {
        $category = new Album();
        $category->title = $request->title;
        $category->artist_id = $request->artist_id;
        $category->genre_id = $request->genre_id;
        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = GlobalFunction::saveFileAndGivePath($file, "album-images");
            $category->image = $path;
        }
        $category->save();

        return response()->json([
            'status' => true,
            'message' => 'Category Added Successfully',
            'data' => $category,
        ]);
        
    }

    public function updateCategory(Request $request)
    {
        $category = Album::where('id', $request->category_id)->first();

        if ($category == null) {
            return response()->json([
                'status' => false,
                'message' => 'Category Not Found',
            ]);
        } else {
            $category->title = $request->title;
            $category->artist_id = $request->artist_id;
            $category->genre_id = $request->genre_id;
            
            if ($request->hasFile('image')) {
                GlobalFunction::deleteFile($category->image); 
                $file = $request->file('image');
                $path = GlobalFunction::saveFileAndGivePath($file, "album-images");
                $category->image = $path;
            }

            $category->save();

            return response()->json([
                'status' => true,
                'message' => 'Category Updated Successfully',
            ]);
        
        }
    }
    
public function getAllCategories()
{
    try {
        $categories = Album::with('artist') // Ensure the Album model has a relation with Artist
            ->get();

        if ($categories->isEmpty()) {
            return response()->json([
                'status' => false,
                'message' => 'No categories found.',
                'data' => []
            ], 200);
        }

        return response()->json([
            'status' => true,
            'message' => 'Categories fetched successfully.',
            'data' => $categories->map(function ($category) {
                return [
                    'id' => $category->id,
                    'artist_id' => $category->artist_id,
                    'artist_name' => $category->artist ? $category->artist->name : 'No Artist', // Join with artist table
                    'genre_id' => $category->genre_id,
                    'title' => $category->title,
                    'category_option' => $category->category_option,
                    'image' => $category->image,
                    'created_at' => $category->created_at,
                    'updated_at' => $category->updated_at,
                ];
            }),
        ], 200);
    } catch (\Exception $e) {
        return response()->json([
            'status' => false,
            'message' => 'Failed to fetch categories.',
            'error' => $e->getMessage(),
        ], 500);
    }
}

    
    public function deleteCategory(Request $request)
    {
        $category = Album::where('id', $request->category_id)->first();

        if ($category == null) {
            return response()->json([
                'status' => false,
                'message' => 'Category Not Found',
            ]);
        }

        $musics = Music::where('category_id', $request->category_id)->get();
        $musics->each->delete();
        
        $articles = Article::where('category_id', $request->category_id)->get();
        $articles->each->delete();

        GlobalFunction::deleteFile($category->image);
        $category->delete();

        return response()->json([
            'status' => true,
            'message' => 'Category Delete Successfully',
        ]);
    } 

public function albumsByGenre($genreId)
{
    // If you'd like to ensure the genre exists:
    $genre = Genre::find($genreId);
    if (!$genre) {
        return response()->json([
            'status'  => false,
            'message' => 'Genre not found.',
            'data'    => [],
        ], 404);
    }

    // Fetch albums belonging to this genre
    $albums = Album::where('genre_id', $genreId)
        ->orderBy('title', 'asc')
        ->get();

    return response()->json([
        'status'  => true,
        'message' => 'Albums fetched successfully.',
        'data'    => $albums,
    ]);
}

public function getTracksByAlbum($category_id)
{
    // Find the album (category) with its artist and genre
    $album = Album::with(['artist', 'genre'])->find($category_id);

    // If album not found, return error response
    if (!$album) {
        return response()->json([
            'status' => false,
            'message' => 'Album not found.',
            'data' => [],
        ], 404);
    }

    // Fetch all tracks in the album
    $tracks = Music::where('category_id', $category_id)->get();

    // Format response data
    return response()->json([
        'status' => true,
        'message' => 'Tracks fetched successfully.',
        'data' => [
            'album' => [
                'id' => $album->id,
                'title' => $album->title,
                'image' => $album->image ? $album->image : null,
                'artist' => $album->artist ? [
                    'id' => $album->artist->id,
                    'name' => $album->artist->name,
                ] : null,
                'genre' => $album->genre ? [
                    'id' => $album->genre->id,
                    'name' => $album->genre->name,
                ] : null,
            ],
            'tracks' => $tracks->map(function ($track) {
                return [
                    'id' => $track->id,
                    'category_id' => $track->category_id,
                    'tag' => $track->tag ?? "",
                    'lyrics' => $track->lyrics ?? "",
                    'title' => $track->title,
                    'plays' => $track->plays ?? 0,
                    'sound' => $track->sound ? $track->sound : null,
                    'type' => $track->type,
                    'is_featured' => $track->is_featured ?? 0,
                    'image' => $track->image ? $track->image : null,
                    'likes' => $track->likes ?? 0,
                    'active' => $track->active ?? 1,
                    'created_at' => $track->created_at,
                    'updated_at' => $track->updated_at,
                ];
            }),
        ],
    ], 200);
}


     
}
