<?php

namespace App\Http\Controllers;

use App\Http\Controllers\MusicController;
use App\Http\Controllers\PlaylistController;
use App\Http\Controllers\PodcastController;

use Illuminate\Http\Request;

class HomeController extends Controller
{
  public function getHomeData()
{
    try {
        // Fetch data from different controllers and functions
        $freshlyRolledBeats = (new MusicController())->topNewSongs();
        $litHitsOfTheDay = (new MusicController())->trendingMusic();
        $bluntBangers = (new PlaylistController())->getTopLikedPlaylists();
        $indicaVibes = (new MusicController())->songsByIndica();
        $sativaSparks = (new MusicController())->songsBySativa();
        $hybridHarmony = (new MusicController())->songsByHybrid();
        $popularpodcast= (new PodcastController())->popularPodcasts();

        // Combine data into sections with titles and descriptions
        $data = [
            [
                'section_title' => 'Freshly Rolled Beats',
                'description' => 'The newest music curated just for you.',
                'items' => $freshlyRolledBeats->original['data'] ?? [],
            ],
            [
                'section_title' => 'Lit Hits of the Week',
                'description' => 'Trending hits that are setting the vibe this week.',
                'items' => $litHitsOfTheDay->original['data'] ?? [],
            ],
            [
                'section_title' => 'Blunt Bangers',
                'description' => 'Top liked playlists to elevate your mood.',
                'items' => $bluntBangers->original['data'] ?? [],
            ],
            [
                'section_title' => 'Indica Vibes',
                'description' => 'Relax and unwind with these indica-inspired tracks.',
                'items' => $indicaVibes->original['data'] ?? [],
            ],
            [
                'section_title' => 'Sativa Sparks',
                'description' => 'Energize your day with these sativa-fueled tunes.',
                'items' => $sativaSparks->original['data'] ?? [],
            ],
            [
                'section_title' => 'Hybrid Harmony',
                'description' => 'A perfect blend of beats to match your vibe.',
                'items' => $hybridHarmony->original['data'] ?? [],
            ],
             [
                'section_title' => 'Hot Podcasts',
                'description' => 'Join the conversations',
                'items' => $popularpodcast->original['data'] ?? [],
            ],
        ];

        // Return the combined response
        return response()->json([
            'status' => true,
            'message' => 'Home data fetched successfully.',
            'data' => $data,
        ], 200);
    } catch (\Exception $e) {
        // Handle exceptions
        return response()->json([
            'status' => false,
            'message' => 'Failed to fetch home data.',
            'error' => $e->getMessage(),
        ], 500);
    }
}


}