<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Playlist;
use App\Models\Podcast;
use App\Models\PodcastCategory;
use App\Models\Album;
use App\Models\User;
use App\Models\Music;
use App\Models\Artist;
use Illuminate\Support\Facades\DB;

class SearchController extends Controller
{
public function unifiedSearch(Request $request)
{
    try {
        $search = $request->input('search', '');
        $perPage = (int) $request->input('per_page', 20); // Default 20 results per category
        $page = (int) $request->input('page', 1);

        // Extract tags from search if applicable
        $searchTags = explode(',', str_replace(' ', '', $search)); // Convert search input into tag array

        // ✅ Random Results When No Search Term is Provided
        if (empty($search)) {
            return response()->json([
                'status' => true,
                'message' => 'Random results fetched successfully.',
                'data' => [
                    'playlists' => Playlist::orderBy('likes', 'desc')
                        ->inRandomOrder()
                        ->paginate($perPage, ['id', 'playlist_name', 'image', 'likes']),

                    'podcasts' => Podcast::join('podcast_categories', 'podcasts.podcast_category_id', '=', 'podcast_categories.id')
                        ->select(
                            'podcasts.id',
                            'podcasts.title',
                            'podcasts.description',
                            'podcast_categories.name as category_name',
                            'podcasts.episode',
                            'podcasts.start_date',
                            'podcasts.end_date',
                            'podcasts.active',
                            'podcasts.likes',
                            'podcasts.plays',
                            'podcasts.type',
                            'podcasts.podcast_category_id',
                             'podcast_categories.image as category_image',
                              'podcasts.created_at',
                            'podcasts.updated_at',
                            'podcasts.episode_number',
                            'podcasts.duration'
                            
                        )
                        ->orderBy('podcasts.plays', 'desc')
                        ->inRandomOrder()
                        ->paginate($perPage),

                    'albums' => Album::inRandomOrder()
                        ->paginate($perPage, ['id', 'title', 'category_option', 'image']),

                    'users' => User::inRandomOrder()
                        ->paginate($perPage, ['id', 'identity', 'fullname', 'image']),

                    'music' => Music::inRandomOrder()
                        ->paginate($perPage, ['id', 'title', 'plays', 'sound', 'type', 'image', 'likes', 'active', 'tag']),

                    'artists' => Artist::inRandomOrder()
                        ->paginate($perPage, ['id', 'name', 'description', 'image']),
                ],
            ], 200);
        }

        // ✅ Search Results with Pagination for Each Section
        return response()->json([
            'status' => true,
            'message' => 'Search results fetched successfully.',
            'data' => [
                'playlists' => Playlist::where('playlist_name', 'LIKE', "%{$search}%")
                    ->orderBy('likes', 'desc')
                    ->paginate($perPage, ['id', 'playlist_name', 'image', 'likes']),

                'podcasts' => Podcast::join('podcast_categories', 'podcasts.podcast_category_id', '=', 'podcast_categories.id')
                    ->where(function ($query) use ($search, $searchTags) {
                        $query->where('podcasts.title', 'LIKE', "%{$search}%");

                        foreach ($searchTags as $tag) {
                            $query->orWhereRaw("FIND_IN_SET(?, podcast_categories.tags)", [$tag]);
                        }
                    })
                    ->select(
                         'podcasts.id',
                            'podcasts.title',
                            'podcasts.description',
                            'podcast_categories.name as category_name',
                            'podcasts.episode',
                            'podcasts.start_date',
                            'podcasts.end_date',
                            'podcasts.active',
                            'podcasts.likes',
                            'podcasts.plays',
                            'podcasts.type',
                            'podcasts.podcast_category_id',
                             'podcast_categories.image as category_image',
                              'podcasts.created_at',
                            'podcasts.updated_at',
                            'podcasts.episode_number',
                            'podcasts.duration'
                    )
                    ->orderBy('podcasts.plays', 'desc')
                    ->paginate($perPage),

                'albums' => Album::where('title', 'LIKE', "%{$search}%")
                    ->paginate($perPage, ['id', 'title', 'category_option', 'image']),

                'users' => User::where('identity', 'LIKE', "%{$search}%")
                    ->orWhere('fullname', 'LIKE', "%{$search}%")
                    ->paginate($perPage, ['id', 'identity', 'fullname', 'image']),

                'music' => Music::where(function ($query) use ($search, $searchTags) {
                    $query->where('title', 'LIKE', "%{$search}%");

                    foreach ($searchTags as $tag) {
                        $query->orWhereRaw("FIND_IN_SET(?, tag)", [$tag]);
                    }
                })
                    ->paginate($perPage, ['id', 'title', 'plays', 'sound', 'type', 'image', 'likes', 'active', 'tag']),

                'artists' => Artist::where('name', 'LIKE', "%{$search}%")
                    ->paginate($perPage, ['id', 'name', 'image']),
            ],
        ], 200);
    } catch (\Exception $e) {
        return response()->json([
            'status' => false,
            'message' => 'An error occurred while searching.',
            'error' => $e->getMessage(),
        ], 500);
    }
}

}
