<?php

namespace App\Http\Controllers;

use App\Models\VibeCheck;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class VibeCheckController extends Controller
{
    /**
     * POST /api/vibe-check
     */
    public function create(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id',
            'vibe_type' => 'required|string|in:Chill,Energized,Foggy,Inspired,Low-Key',
            'notes' => 'nullable|string'
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
        }

        // Define messages for each vibe
        $messages = [
            'Chill' => "Your vibe is chill. Here’s to a more relaxed, grounded kind of day.",
            'Energized' => "Your vibe is lit! Let’s channel that energy into something amazing.",
            'Foggy' => "Feeling a little foggy? Let’s help you find clarity and light today.",
            'Inspired' => "You’re in a creative flow. Let’s make today beautifully expressive.",
            'Low-Key' => "Today feels soft and slow — we’ve got just the vibes for that.",
        ];

        $vibe = VibeCheck::create([
            'user_id' => $request->user_id,
            'vibe_type' => $request->vibe_type,
            'greeting_message' => $messages[$request->vibe_type],
            'notes' => $request->notes,
        ]);

        return response()->json([
            'status' => true,
            'message' => 'Vibe saved successfully',
            'data' => $vibe
        ]);
    }

    /**
     * GET /api/vibe-check/history
     */
    public function getHistory(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'user_id' => 'required|exists:users,id',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => $validator->errors()->first()]);
        }

        $vibes = VibeCheck::where('user_id', $request->user_id)
                    ->orderBy('created_at', 'desc')
                    ->take(10)
                    ->get();

        return response()->json([
            'status' => true,
            'data' => $vibes
        ]);
    }
    
}
