<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Genre extends Model
{
    protected $fillable = [
        'name',
        'description',
        'parent_id',
        'type', // <-- add this so mass-assignment includes "type"
    ];

    // Relationship to fetch sub-genres
    public function subGenres()
    {
        return $this->hasMany(Genre::class, 'parent_id');
    }

    public function parent()
    {
        return $this->belongsTo(Genre::class, 'parent_id');
    }

    public function children()
    {
        return $this->hasMany(Genre::class, 'parent_id');
    }

    /**
     * (Optional) Helper method returning all valid type options.
     * Useful if you want to build dropdowns or do validations in a form.
     */
    public static function getTypeOptions()
    {
        return [
            'indica' => 'Indica',
            'sativa' => 'Sativa',
            'hybrid' => 'Hybrid',
            'meditation' => 'Meditation',
        ];
    }
}
