<?php 

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/
use App\Http\Controllers\HomeController;
use App\Http\Controllers\EqCommentController;
use App\Http\Controllers\MusicController;
use App\Http\Controllers\EqController;
use App\Http\Controllers\SearchController;
use App\Http\Controllers\EqwController;
use App\Http\Controllers\PlaylistController;
use App\Http\Controllers\PlaylistMusicController;
use App\Http\Controllers\StrainController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\FollowerController;
use App\Http\Controllers\SettingsController;
use App\Http\Controllers\StrainTypeController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ArtistController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\HeadphoneAdController;
use App\Http\Controllers\VibeCheckController;
use App\Http\Controllers\VibeOptionController;
use App\Http\Controllers\AdminVibeOptionController;
use App\Http\Controllers\GuidedSessionController;
use App\Http\Controllers\DynamicSessionController;
use App\Http\Controllers\GuidedSessionTemplateController;
use App\Http\Controllers\UserSessionFeedbackController;

use App\Http\Controllers\GenreController;
use App\Http\Controllers\PodcastCategoryController;
use App\Http\Controllers\PodcastController;
use Illuminate\Support\Facades\Route;

Route::post('testSearch', [SettingsController::class, 'testSearch'])->name('testSearch');
Route::get('/search', [SearchController::class, 'unifiedSearch'])->middleware('checkHeader');

Route::prefix('ads')->middleware('checkHeader')->group(function () {
    Route::get('headphones', [HeadphoneAdController::class, 'fetchAd']);
    Route::post('headphones', [HeadphoneAdController::class, 'createAd']); // Admin only
});

Route::get('/guided-session-templates', [GuidedSessionTemplateController::class, 'index'])->middleware('checkHeader');
Route::get('/guided-session-templates/{id}/launch', [DynamicSessionController::class, 'launch'])->middleware('checkHeader');

Route::post('/session-feedback', [UserSessionFeedbackController::class, 'submit'])->middleware('checkHeader');

Route::prefix('guided-sessions')->middleware('checkHeader')->group(function () {
    Route::get('/', [GuidedSessionController::class, 'listAllSessions']);     // browse
    Route::get('/{id}', [GuidedSessionController::class, 'show']);            // view details
    Route::get('/recommend', [GuidedSessionController::class, 'getRecommendedSession']); // smart suggestion
});

Route::prefix('admin/vibe-options')->name('admin.vibes.')->middleware('checkHeader')->group(function () {
    Route::get('/', [AdminVibeOptionController::class, 'index'])->name('index');
    Route::get('/create', [AdminVibeOptionController::class, 'create'])->name('create');
    Route::post('/store', [AdminVibeOptionController::class, 'store'])->name('store');
    Route::get('/edit/{id}', [AdminVibeOptionController::class, 'edit'])->name('edit');
    Route::post('/update/{id}', [AdminVibeOptionController::class, 'update'])->name('update');
    Route::delete('/delete/{id}', [AdminVibeOptionController::class, 'destroy'])->name('destroy');
});
Route::post('fetchAllData', [SettingsController::class, 'fetchAllData'])->middleware('checkHeader');
Route::post('registerUser', [UserController::class, 'registerUser'])->middleware('checkHeader');
Route::post('editProfile', [UserController::class, 'editProfile'])->middleware('checkHeader');
Route::post('deleteMyAccount', [UserController::class, 'deleteMyAccount'])->middleware('checkHeader');
Route::post('fetchUserProfile', [UserController::class, 'fetchUserProfile'])->middleware('checkHeader');
Route::post('logout', [UserController::class, 'logout'])->middleware('checkHeader');
Route::get('/users/paginated', [UserController::class, 'getPaginatedUsers'])->middleware('checkHeader');;


Route::post('playSound', [MusicController::class, 'playSound'])->middleware('checkHeader');
Route::post('getEq',[EqController::class,'getEqs'])->middleware('checkHeader');
Route::post('getEqw',[EqwController::class,'getEqws'])->middleware('checkHeader');
Route::post('register-strain', [StrainController::class, 'addStrain'])->middleware('checkHeader');
Route::post('{eq_id}/like', [EqController::class, 'like'])->middleware('checkHeader');


Route::get('/trending-music', [MusicController::class, "trendingMusic"])->middleware('checkHeader');
Route::get('popular-music', [MusicController::class, 'popularMusic'])->middleware('checkHeader');
Route::post('/like-music', [MusicController::class, "likeSound"])->middleware("checkHeader");
Route::get('/top-played-categories', [MusicController::class, 'topPlayedCategories']);

Route::get('/albums/{category_id}/tracks', [CategoryController::class, 'getTracksByAlbum']);

Route::prefix('vibe-check')->middleware('checkHeader')->group(function () {
    Route::post('/', [VibeCheckController::class, 'create']);
    Route::get('/history', [VibeCheckController::class, 'getHistory']);
Route::get('vibe-check/options', [VibeOptionController::class, 'list']);

});
Route::prefix('playlists')->middleware('checkHeader')->group(function () {
    Route::post('/', [PlaylistController::class, 'createPlaylist']);
    Route::post('/add-music', [PlaylistController::class, 'addMusicToPlaylist']);
    Route::post('/play-track', [PlaylistController::class, 'playTrack']);
    Route::post('/{id}/like', [PlaylistController::class, 'likePlaylist']);
    Route::get('/delete/{id}', [PlaylistController::class, 'deletePlaylist']);
});

Route::get('/playlists/details', [PlaylistController::class, 'getPlaylistsWithDetails']);
Route::get('/eqs/search', [EqController::class, 'wildcardSearch']);


Route::prefix('eq-comment')->middleware('checkHeader')->group(function () {
    Route::get("{strain_id}", [EqCommentController::class, "index"]);
    Route::post("", [EqCommentController::class, "store"]);
    Route::post('{comment_id}/like', [EqCommentController::class, 'like']);
    Route::put('{comment_id}', [EqCommentController::class, 'update']);
    Route::post('/{comment_id}/unlike', [EqCommentController::class, 'unlike']);
Route::post('{comment_id}/toggle-like', [EqCommentController::class, 'toggleLike']);




});

Route::prefix('user')->middleware('checkHeader')->group(function () {
    Route::get('has-profile', [ProfileController::class, 'hasProfile']);
    Route::post('profile', [ProfileController::class, 'saveProfile']);
    Route::get('profile', [ProfileController::class, 'getProfile']);
     Route::get('has-headphones', [UserController::class, 'hasHeadphones']);
    Route::post('update-headphones', [UserController::class, 'updateHeadphones']);
});


Route::prefix('strain-type')->middleware('checkHeader')->group(function () {
    Route::post('/', [StrainTypeController::class, 'store']);
    Route::get('/', [StrainTypeController::class, 'index']);
    Route::get('{id}', [StrainTypeController::class, 'show']);
    Route::put('{id}', [StrainTypeController::class, 'update']);
    Route::delete('{id}', [StrainTypeController::class, 'destroy']);
});

Route::prefix('podcast-category')->middleware('checkHeader')->group(function () {
    Route::post('/', [PodcastCategoryController::class, 'store_api']);
    Route::get('/', [PodcastCategoryController::class, 'index_api']);
    Route::get('{id}', [PodcastCategoryController::class, 'show_api']);
    Route::put('{id}', [PodcastCategoryController::class, 'update_api']);
    Route::delete('{id}', [PodcastCategoryController::class, 'destroy_api']);
});

Route::prefix('podcast')->middleware('checkHeader')->group(function () {
Route::get('/', [PodcastCategoryController::class, 'getPodcastsWithEpisodes']);
Route::get('/{podcastCategoryId}/episodes', [PodcastController::class, 'getEpisodesByPodcast']);
Route::post('/follow', [PodcastController::class, 'toggleFollow']); // Follow/Unfollow
Route::get('/follow-status/{podcast_id}/{user_id}', [PodcastController::class, 'checkFollowStatus']); // Check follow status
Route::get('/followers/{podcast_id}', [PodcastController::class, 'getFollowers']); // Get followers
    Route::post('/', [PodcastController::class, 'store']);
    Route::post('/{id}', [PodcastController::class, 'update']); // For HTML form method spoofing
    Route::put('/{id}', [PodcastController::class, 'update']);
    Route::delete('/{id}', [PodcastController::class, 'destroy']);
});

Route::prefix('podcasts')->middleware('checkHeader')->group(function () {
Route::get('/', [PodcastCategoryController::class, 'getPodcastsWithEpisodes']);
Route::get('/{id}', [PodcastController::class, 'show']);
 // For DataTables     Route::post('/list', [PodcastController::class, 'podcastList']);

    Route::get('category/{category_id}', [PodcastController::class, 'podcastByCategory']);
});


Route::post('/podcasts/{id}/increment-plays', [PodcastController::class, 'incrementPlays']);
Route::post('/podcasts/{id}/increment-likes', [PodcastController::class, 'incrementLikes']);
Route::get('/popular-podcasts', [PodcastController::class, 'popularPodcasts']);


Route::get('/artists', [ArtistController::class, 'listAll'])->middleware('checkHeader');

Route::prefix('artist')->middleware('checkHeader')->group(function () {
    Route::post('/create', [ArtistController::class, 'create']);
    Route::put('/update/{id}', [ArtistController::class, 'update']);
    Route::get('/{id}', [ArtistController::class, 'fetch']);
    Route::delete('/delete/{id}', [ArtistController::class, 'delete']);
    Route::get('/search', [ArtistController::class, 'search']);
    Route::get('/{artist_id}/albums', [ArtistController::class, 'getAlbumsByArtist']);

});

Route::prefix('genre')->middleware('checkHeader')->group(function () {
    Route::post('create', [GenreController::class, 'create']);
    Route::put('update/{id}', [GenreController::class, 'update']);
    Route::delete('delete/{id}', [GenreController::class, 'delete']);
    Route::get('{id}', [GenreController::class, 'fetch']);
});

Route::get('genres', [GenreController::class, 'listAll'])->middleware('checkHeader');
Route::get('/genres/{genreId}/albums', [CategoryController::class, 'albumsByGenre'])->middleware('checkHeader');

Route::get('/strains/search', [StrainController::class, 'searchStrains']);


Route::get('/albums', [CategoryController::class, 'getAllCategories'])->middleware('checkHeader');

Route::middleware('checkHeader')->group(function () {
    Route::get('/user/{userId}/followers-count', [FollowerController::class, 'countFollowersAndFollowing']);
    Route::get('/user/{userId}/followers', [FollowerController::class, 'getFollowers']);
    Route::get('/user/{userId}/following', [FollowerController::class, 'getFollowing']);
    Route::post('/user/add-follower', [FollowerController::class, 'addFollower']);
    Route::get('/user/remove-follower', [FollowerController::class, 'removeFollower']);
    Route::get('/user/{userId}/follow-status/{followerId}', [FollowerController::class, 'checkFollowStatus']);
});



Route::get('/user/{userId}/playlists', [PlaylistController::class, 'getUserPlaylists'])->middleware('checkHeader');
Route::get('/playlists/all', [PlaylistController::class, 'getAllPlaylists'])->middleware('checkHeader');
Route::post('/playlist/remove-music', [PlaylistMusicController::class, 'removeMusicFromPlaylist'])->middleware('checkHeader');



Route::get('/home', [HomeController::class, 'getHomeData'])->middleware('checkHeader');

Route::post('/playPodcast', [PodcastController::class, 'playPodcast'])->middleware('checkHeader');
Route::post('/log-eq-activity', [EqController::class, 'logEqActivity'])->middleware(['checkHeader']);
Route::get('/playlist/music', [PlaylistMusicController::class, 'getPlaylistMusic'])->middleware('checkHeader');

